"vim utility plugin
"colornames.vim - Show named colors - hex code, name, colorized in a window
"
"Walter Hutchins
"Last change: July 17, 2006
"Version 1.5
"
"Setup:
"      copy to ~./vim/plugin
"      
"      optionally set up command:
"      command! -nargs=* Cna call Showhexcolornames(<f-args>)
"
"
" Named colors work in gui only - no color in xterm
"
" cterm/gui colors work in gui and 256 xterms
"
"Showhexcolornames() - show all, do not clear syntax
"
"Showhexcolornames(b) - show all (background), do not clear syntax
"
"Showhexcolornames(r) - same as b
"
"Showhexcolornames(v) - Open window vertical split
"
"Showhexcolornames(h) - Open window horizontal split (default if not 'v')
"
"Showhexcolornames(9) - show all after clearing syntax
"
"Showcolornames(n) - show nth 182 named colors or nth cterm colors
"                    do not clear syntax.
"                    [n: 1-3, named]
"                    [n: 4-5, cterm]
"                    [n: 10,11, cterm (hsv sorted)]
"                    [n: 12-14 named (hsv sorted)]
"                    [n: 20-24 mixed (hsv sorted)]
"                    [hsv sorted: black->red->green->blue->purple]
"
"Showcolornames(9,n) - show nth 182 named colors or nth cterm colors
"                      after clearing syntax.
"                    [n: 1-3, named]
"                    [n: 4-5, cterm]
"                    [n: 10,11, cterm (hsv sorted)]
"                    [n: 12-14 named (hsv sorted)]
"                    [n: 20-24 mixed (hsv sorted)]
"                    [hsv sorted: black->red->green->blue->purple]
"
"    n, b, v, 9 may be combined as in
"                            Showhexcolors(9,4,5) - clear/ show all cterm
"                            Showhexcolors(9,1,2,3) - clear/ show all named
"                            Showhexcolors(9,r,4) - clear/ show 1st cterm
"                                                   group in background blocks
"                            Showhexcolors(9,v,5,1) - clear/ vertical split/
"                                                   show 2nd cterm group
"                                                   and 1st named colors group
"
"
"    n=0 - all named colors
"    n=6 - all cterm colors
"    n=7 - all mixed colors (hsv sorted)
"    n=15 - all named colors (hsv sorted)
"    n=16 - all cterm colors (hsv sorted)
"
"    n=20 - mixed, hsv sorted, "blacks to whites
"    n=21 - mixed, hsv sorted, "reds to yellows
"    n=22 - mixed, hsv sorted, "yellows to greens
"    n=23 - mixed, hsv sorted, "blues
"    n=24 - mixed, hsv sorted, "purples
"
"    r   - same as b (or background, or reverse) 
"
"Showhexcolornames(8) - cleanup highlighting added by Showhexcolornames
"
"vim < 7 only can show 223 simultaneous highlight groups.
"        Once that limit is exceeded, the colors will be random until exit.
"        Therefore use 1, 2, 3, 4, or 5 (group of) colors in call.
"        Also use 9 - clear syntax, since it needs to clear syntax 
"        to avoid the 223 limit which makes random colors.
"        Showhexcolornames(8) may be able to cleanup and continue in the gui
"        without random colors.
"
"vim 7 does not have max 223 colors problem

function s:Synclear()
    "syntax clear
    hi clear
endfunction

function s:Cleanup()
    new
    let save_b=@b
    let save_more=&more
    set nomore
    redir @b
    hi
    redir END
    put =@b
    g/^\(col_[A-Fa-f0-9]\{6,6}\)\@!/d
    g/^\(col_cterm_\d\+\)\@!/d
    %s/\s.*//e
    %s/\(^.*\)/hi clear \1/e
    % yank b
    exec @b
    %s/hi clear/syntax clear/e
    % yank b
    exec @b
    let @b=save_b
    let &more=save_more
    set nomodified
    q
endfunction

function s:Cleanup2()
    if bufexists("NamedColors") && bufloaded("NamedColors")
        exec 'drop NamedColors'
    else
        if s:vert_horiz == "v"
            vnew
        else
            new
        endif
        exec 'edit NamedColors'
    endif
    let save_b=@b
    silent g/^$/d
    silent %s/\(^.*\)/hi clear col_\1/e
    silent % yank b
    silent @b
    silent %s/hi clear/syntax clear/e
    silent % yank b
    silent @b
    let @b=save_b
endfunction

function Showhexcolornames(...)
let save_a=@a
let rgbhex=""
let ground='fg'
let rbf=""
let s:vert_horiz="h"
let subset=-1
let clear_syntax=0
let cleanup=0
let remargs=a:0
let nxtarg=0
while remargs > 0
    let nxtarg=nxtarg + 1
    exec 'let thearg=a:'.nxtarg
    "if type(thearg) == 0
        if thearg =~? '^r' || thearg =~? '^b'
            let ground='bg'
	    let rbf=' guifg=#000000 ctermfg=0'
        elseif thearg =~? '^v'
            let s:vert_horiz="v"
        elseif thearg =~? '^h'
            let s:vert_horiz="h"
	elseif 0 <= thearg && thearg <= 7
            let subset=thearg
            let rgbhex=rgbhex . s:Rgbhex(subset)
	elseif 10 <= thearg && thearg <=24
            let subset=thearg
            let rgbhex=rgbhex . s:Rgbhex(7)
        elseif thearg == 9
            let clear_syntax=1
        elseif thearg == 8
            let cleanup=1
        endif
    "endif
    let remargs=remargs - 1
endwhile
if subset == -1
    let rgbhex=rgbhex . s:Rgbhex()
endif

if cleanup == 1
    call s:Cleanup2()
"this trick avoids "PRESS ENTER" prompt
"0 append
".
    return
endif

"let rgbhex=s:Rgbhex(subset)

if bufexists("NamedColors") && bufloaded("NamedColors")
    exec 'drop NamedColors'
else
    if s:vert_horiz == "v"
        vnew
    else
        new
    endif
    exec 'edit NamedColors'
    silent g/^$/d
endif

"maybe you dont want to
if clear_syntax == 1
    call s:Cleanup2()
endif
1,$d
silent put =rgbhex
g/^$/d
if subset == 10
    g/^[A-Fa-f0-9]\{6,6}_/d
    128,$d
elseif subset == 11
    g/^[A-Fa-f0-9]\{6,6}_/d
    1,128d
elseif subset == 12
    g/^cterm_/d
    183-5,$d
elseif subset == 13
    g/^cterm_/d
    1,182-5d
    183+5,$d
elseif subset == 14
    g/^cterm_/d
    1,$-184d
elseif subset == 15
    g/^cterm_/d
elseif subset == 16
    g/^[A-Fa-f0-9]\{6,6}_/d
elseif subset == 20
    "blacks to whites
    147,$d
elseif subset == 21
    "reds to yellows
    1,146d
    183,$d
elseif subset == 22
    "yellows to greens
    1,146d
    1,182d
    183-2,$d
elseif subset == 23
    "blues
    1,146d
    1,182d
    1,182-2d
    161-6,$d
elseif subset == 24
    "purples
    1,$-134-2-6d
endif

"Prior to vim 7, :help limit shows - highlighting different types: 223
"Subtracting an average of 39 types from 223 = 184. Stop adding types at 184.
let @a=""
let chk=""
if version < 700      
    let chk=line("$")
    if chk > 184
	184,$d a
    endif
endif

silent g/^[A-Fa-f0-9]\{6,6}_/ exec 'hi col_'.expand("<cword>").' gui'.ground.'='.strpart(expand("<cword>"),match(expand("<cword>"),"_")+1).rbf | exec 'syn keyword col_'.expand("<cword>").' '.expand("<cword>")
silent g/^cterm_\d\+/ exec 'hi col_'.expand("<cword>").' cterm'.ground.'='.strpart(expand("<cword>"),6).' gui'.ground.'=#'.strpart(expand("<cword>"),strlen(expand("<cword>"))-6).rbf| exec 'syn keyword col_'.expand("<cword>")." ".expand("<cword>")

"Prior to vim 7, :help limit shows - highlighting different types: 223
"Show the remaining color names unhighlighted.
if version < 700 
    if chk > 184
	$
        put a
    endif
endif

1
" we don't want to save the temporary file
set nomodified
"this trick avoids "PRESS ENTER" prompt
0 append
.
let @a=save_a
endfunction

function s:Rgbhex(...)
let rgbhex1=""
let rgbhex2=""
let rgbhex3=""
let cterm1=""
let cterm2=""
let rgbhex1=rgbhex1 . "fffafa_snow" . "\n"
let rgbhex1=rgbhex1 . "f8f8ff_GhostWhite" . "\n"
let rgbhex1=rgbhex1 . "f5f5f5_WhiteSmoke" . "\n"
let rgbhex1=rgbhex1 . "dcdcdc_gainsboro" . "\n"
let rgbhex1=rgbhex1 . "fffaf0_FloralWhite" . "\n"
let rgbhex1=rgbhex1 . "fdf5e6_OldLace" . "\n"
let rgbhex1=rgbhex1 . "faf0e6_linen" . "\n"
let rgbhex1=rgbhex1 . "faebd7_AntiqueWhite" . "\n"
let rgbhex1=rgbhex1 . "ffefd5_PapayaWhip" . "\n"
let rgbhex1=rgbhex1 . "ffebcd_BlanchedAlmond" . "\n"
let rgbhex1=rgbhex1 . "ffe4c4_bisque" . "\n"
let rgbhex1=rgbhex1 . "ffdab9_PeachPuff" . "\n"
let rgbhex1=rgbhex1 . "ffdead_NavajoWhite" . "\n"
let rgbhex1=rgbhex1 . "ffe4b5_moccasin" . "\n"
let rgbhex1=rgbhex1 . "fff8dc_cornsilk" . "\n"
let rgbhex1=rgbhex1 . "fffff0_ivory" . "\n"
let rgbhex1=rgbhex1 . "fffacd_LemonChiffon" . "\n"
let rgbhex1=rgbhex1 . "fff5ee_seashell" . "\n"
let rgbhex1=rgbhex1 . "f0fff0_honeydew" . "\n"
let rgbhex1=rgbhex1 . "f5fffa_MintCream" . "\n"
let rgbhex1=rgbhex1 . "f0ffff_azure" . "\n"
let rgbhex1=rgbhex1 . "f0f8ff_AliceBlue" . "\n"
let rgbhex1=rgbhex1 . "e6e6fa_lavender" . "\n"
let rgbhex1=rgbhex1 . "fff0f5_LavenderBlush" . "\n"
let rgbhex1=rgbhex1 . "ffe4e1_MistyRose" . "\n"
let rgbhex1=rgbhex1 . "ffffff_white" . "\n"
let rgbhex1=rgbhex1 . "000000_black" . "\n"
let rgbhex1=rgbhex1 . "2f4f4f_DarkSlateGray" . "\n"
let rgbhex1=rgbhex1 . "696969_DimGray" . "\n"
let rgbhex1=rgbhex1 . "708090_SlateGray" . "\n"
let rgbhex1=rgbhex1 . "778899_LightSlateGray" . "\n"
let rgbhex1=rgbhex1 . "bebebe_gray" . "\n"
let rgbhex1=rgbhex1 . "d3d3d3_LightGray" . "\n"
let rgbhex1=rgbhex1 . "191970_MidnightBlue" . "\n"
let rgbhex1=rgbhex1 . "000080_navy" . "\n"
let rgbhex1=rgbhex1 . "6495ed_CornflowerBlue" . "\n"
let rgbhex1=rgbhex1 . "483d8b_DarkSlateBlue" . "\n"
let rgbhex1=rgbhex1 . "6a5acd_SlateBlue" . "\n"
let rgbhex1=rgbhex1 . "7b68ee_MediumSlateBlue" . "\n"
let rgbhex1=rgbhex1 . "8470ff_LightSlateBlue" . "\n"
let rgbhex1=rgbhex1 . "0000cd_MediumBlue" . "\n"
let rgbhex1=rgbhex1 . "4169e1_RoyalBlue" . "\n"
let rgbhex1=rgbhex1 . "0000ff_blue" . "\n"
let rgbhex1=rgbhex1 . "1e90ff_DodgerBlue" . "\n"
let rgbhex1=rgbhex1 . "00bfff_DeepSkyBlue" . "\n"
let rgbhex1=rgbhex1 . "87ceeb_SkyBlue" . "\n"
let rgbhex1=rgbhex1 . "87cefa_LightSkyBlue" . "\n"
let rgbhex1=rgbhex1 . "4682b4_SteelBlue" . "\n"
let rgbhex1=rgbhex1 . "b0c4de_LightSteelBlue" . "\n"
let rgbhex1=rgbhex1 . "add8e6_LightBlue" . "\n"
let rgbhex1=rgbhex1 . "b0e0e6_PowderBlue" . "\n"
let rgbhex1=rgbhex1 . "afeeee_PaleTurquoise" . "\n"
let rgbhex1=rgbhex1 . "00ced1_DarkTurquoise" . "\n"
let rgbhex1=rgbhex1 . "48d1cc_MediumTurquoise" . "\n"
let rgbhex1=rgbhex1 . "40e0d0_turquoise" . "\n"
let rgbhex1=rgbhex1 . "00ffff_cyan" . "\n"
let rgbhex1=rgbhex1 . "e0ffff_LightCyan" . "\n"
let rgbhex1=rgbhex1 . "5f9ea0_CadetBlue" . "\n"
let rgbhex1=rgbhex1 . "66cdaa_MediumAquamarine" . "\n"
let rgbhex1=rgbhex1 . "7fffd4_aquamarine" . "\n"
let rgbhex1=rgbhex1 . "006400_DarkGreen" . "\n"
let rgbhex1=rgbhex1 . "556b2f_DarkOliveGreen" . "\n"
let rgbhex1=rgbhex1 . "8fbc8f_DarkSeaGreen" . "\n"
let rgbhex1=rgbhex1 . "2e8b57_SeaGreen" . "\n"
let rgbhex1=rgbhex1 . "3cb371_MediumSeaGreen" . "\n"
let rgbhex1=rgbhex1 . "20b2aa_LightSeaGreen" . "\n"
let rgbhex1=rgbhex1 . "98fb98_PaleGreen" . "\n"
let rgbhex1=rgbhex1 . "00ff7f_SpringGreen" . "\n"
let rgbhex1=rgbhex1 . "7cfc00_LawnGreen" . "\n"
let rgbhex1=rgbhex1 . "00ff00_green" . "\n"
let rgbhex1=rgbhex1 . "7fff00_chartreuse" . "\n"
let rgbhex1=rgbhex1 . "00fa9a_MediumSpringGreen" . "\n"
let rgbhex1=rgbhex1 . "adff2f_GreenYellow" . "\n"
let rgbhex1=rgbhex1 . "32cd32_LimeGreen" . "\n"
let rgbhex1=rgbhex1 . "9acd32_YellowGreen" . "\n"
let rgbhex1=rgbhex1 . "228b22_ForestGreen" . "\n"
let rgbhex1=rgbhex1 . "6b8e23_OliveDrab" . "\n"
let rgbhex1=rgbhex1 . "bdb76b_DarkKhaki" . "\n"
let rgbhex1=rgbhex1 . "f0e68c_khaki" . "\n"
let rgbhex1=rgbhex1 . "eee8aa_PaleGoldenrod" . "\n"
let rgbhex1=rgbhex1 . "fafad2_LightGoldenrodYellow" . "\n"
let rgbhex1=rgbhex1 . "ffffe0_LightYellow" . "\n"
let rgbhex1=rgbhex1 . "ffff00_yellow" . "\n"
let rgbhex1=rgbhex1 . "ffd700_gold" . "\n"
let rgbhex1=rgbhex1 . "eedd82_LightGoldenrod" . "\n"
let rgbhex1=rgbhex1 . "daa520_goldenrod" . "\n"
let rgbhex1=rgbhex1 . "b8860b_DarkGoldenrod" . "\n"
let rgbhex1=rgbhex1 . "bc8f8f_RosyBrown" . "\n"
let rgbhex1=rgbhex1 . "cd5c5c_IndianRed" . "\n"
let rgbhex1=rgbhex1 . "8b4513_SaddleBrown" . "\n"
let rgbhex1=rgbhex1 . "a0522d_sienna" . "\n"
let rgbhex1=rgbhex1 . "cd853f_peru" . "\n"
let rgbhex1=rgbhex1 . "deb887_burlywood" . "\n"
let rgbhex1=rgbhex1 . "f5f5dc_beige" . "\n"
let rgbhex1=rgbhex1 . "f5deb3_wheat" . "\n"
let rgbhex1=rgbhex1 . "f4a460_SandyBrown" . "\n"
let rgbhex1=rgbhex1 . "d2b48c_tan" . "\n"
let rgbhex1=rgbhex1 . "d2691e_chocolate" . "\n"
let rgbhex1=rgbhex1 . "b22222_firebrick" . "\n"
let rgbhex1=rgbhex1 . "a52a2a_brown" . "\n"
let rgbhex1=rgbhex1 . "e9967a_DarkSalmon" . "\n"
let rgbhex1=rgbhex1 . "fa8072_salmon" . "\n"
let rgbhex1=rgbhex1 . "ffa07a_LightSalmon" . "\n"
let rgbhex1=rgbhex1 . "ffa500_orange" . "\n"
let rgbhex1=rgbhex1 . "ff8c00_DarkOrange" . "\n"
let rgbhex1=rgbhex1 . "ff7f50_coral" . "\n"
let rgbhex1=rgbhex1 . "f08080_LightCoral" . "\n"
let rgbhex1=rgbhex1 . "ff6347_tomato" . "\n"
let rgbhex1=rgbhex1 . "ff4500_OrangeRed" . "\n"
let rgbhex1=rgbhex1 . "ff0000_red" . "\n"
let rgbhex1=rgbhex1 . "ff69b4_HotPink" . "\n"
let rgbhex1=rgbhex1 . "ff1493_DeepPink" . "\n"
let rgbhex1=rgbhex1 . "ffc0cb_pink" . "\n"
let rgbhex1=rgbhex1 . "ffb6c1_LightPink" . "\n"
let rgbhex1=rgbhex1 . "db7093_PaleVioletRed" . "\n"
let rgbhex1=rgbhex1 . "b03060_maroon" . "\n"
let rgbhex1=rgbhex1 . "c71585_MediumVioletRed" . "\n"
let rgbhex1=rgbhex1 . "d02090_VioletRed" . "\n"
let rgbhex1=rgbhex1 . "ff00ff_magenta" . "\n"
let rgbhex1=rgbhex1 . "ee82ee_violet" . "\n"
let rgbhex1=rgbhex1 . "dda0dd_plum" . "\n"
let rgbhex1=rgbhex1 . "da70d6_orchid" . "\n"
let rgbhex1=rgbhex1 . "ba55d3_MediumOrchid" . "\n"
let rgbhex1=rgbhex1 . "9932cc_DarkOrchid" . "\n"
let rgbhex1=rgbhex1 . "9400d3_DarkViolet" . "\n"
let rgbhex1=rgbhex1 . "8a2be2_BlueViolet" . "\n"
let rgbhex1=rgbhex1 . "a020f0_purple" . "\n"
let rgbhex1=rgbhex1 . "9370db_MediumPurple" . "\n"
let rgbhex1=rgbhex1 . "d8bfd8_thistle" . "\n"
let rgbhex1=rgbhex1 . "fffafa_snow1" . "\n"
let rgbhex1=rgbhex1 . "eee9e9_snow2" . "\n"
let rgbhex1=rgbhex1 . "cdc9c9_snow3" . "\n"
let rgbhex1=rgbhex1 . "8b8989_snow4" . "\n"
let rgbhex1=rgbhex1 . "fff5ee_seashell1" . "\n"
let rgbhex1=rgbhex1 . "eee5de_seashell2" . "\n"
let rgbhex1=rgbhex1 . "cdc5bf_seashell3" . "\n"
let rgbhex1=rgbhex1 . "8b8682_seashell4" . "\n"
let rgbhex1=rgbhex1 . "ffefdb_AntiqueWhite1" . "\n"
let rgbhex1=rgbhex1 . "eedfcc_AntiqueWhite2" . "\n"
let rgbhex1=rgbhex1 . "cdc0b0_AntiqueWhite3" . "\n"
let rgbhex1=rgbhex1 . "8b8378_AntiqueWhite4" . "\n"
let rgbhex1=rgbhex1 . "ffe4c4_bisque1" . "\n"
let rgbhex1=rgbhex1 . "eed5b7_bisque2" . "\n"
let rgbhex1=rgbhex1 . "cdb79e_bisque3" . "\n"
let rgbhex1=rgbhex1 . "8b7d6b_bisque4" . "\n"
let rgbhex1=rgbhex1 . "ffdab9_PeachPuff1" . "\n"
let rgbhex1=rgbhex1 . "eecbad_PeachPuff2" . "\n"
let rgbhex1=rgbhex1 . "cdaf95_PeachPuff3" . "\n"
let rgbhex1=rgbhex1 . "8b7765_PeachPuff4" . "\n"
let rgbhex1=rgbhex1 . "ffdead_NavajoWhite1" . "\n"
let rgbhex1=rgbhex1 . "eecfa1_NavajoWhite2" . "\n"
let rgbhex1=rgbhex1 . "cdb38b_NavajoWhite3" . "\n"
let rgbhex1=rgbhex1 . "8b795e_NavajoWhite4" . "\n"
let rgbhex1=rgbhex1 . "fffacd_LemonChiffon1" . "\n"
let rgbhex1=rgbhex1 . "eee9bf_LemonChiffon2" . "\n"
let rgbhex1=rgbhex1 . "cdc9a5_LemonChiffon3" . "\n"
let rgbhex1=rgbhex1 . "8b8970_LemonChiffon4" . "\n"
let rgbhex1=rgbhex1 . "fff8dc_cornsilk1" . "\n"
let rgbhex1=rgbhex1 . "eee8cd_cornsilk2" . "\n"
let rgbhex1=rgbhex1 . "cdc8b1_cornsilk3" . "\n"
let rgbhex1=rgbhex1 . "8b8878_cornsilk4" . "\n"
let rgbhex1=rgbhex1 . "fffff0_ivory1" . "\n"
let rgbhex1=rgbhex1 . "eeeee0_ivory2" . "\n"
let rgbhex1=rgbhex1 . "cdcdc1_ivory3" . "\n"
let rgbhex1=rgbhex1 . "8b8b83_ivory4" . "\n"
let rgbhex1=rgbhex1 . "f0fff0_honeydew1" . "\n"
let rgbhex1=rgbhex1 . "e0eee0_honeydew2" . "\n"
let rgbhex1=rgbhex1 . "c1cdc1_honeydew3" . "\n"
let rgbhex1=rgbhex1 . "838b83_honeydew4" . "\n"
let rgbhex1=rgbhex1 . "fff0f5_LavenderBlush1" . "\n"
let rgbhex1=rgbhex1 . "eee0e5_LavenderBlush2" . "\n"
let rgbhex1=rgbhex1 . "cdc1c5_LavenderBlush3" . "\n"
let rgbhex1=rgbhex1 . "8b8386_LavenderBlush4" . "\n"
let rgbhex1=rgbhex1 . "ffe4e1_MistyRose1" . "\n"
let rgbhex1=rgbhex1 . "eed5d2_MistyRose2" . "\n"
let rgbhex1=rgbhex1 . "cdb7b5_MistyRose3" . "\n"
let rgbhex1=rgbhex1 . "8b7d7b_MistyRose4" . "\n"
let rgbhex1=rgbhex1 . "f0ffff_azure1" . "\n"
let rgbhex1=rgbhex1 . "e0eeee_azure2" . "\n"
let rgbhex1=rgbhex1 . "c1cdcd_azure3" . "\n"
let rgbhex1=rgbhex1 . "838b8b_azure4" . "\n"
let rgbhex2=rgbhex2 . "836fff_SlateBlue1" . "\n"
let rgbhex2=rgbhex2 . "7a67ee_SlateBlue2" . "\n"
let rgbhex2=rgbhex2 . "6959cd_SlateBlue3" . "\n"
let rgbhex2=rgbhex2 . "473c8b_SlateBlue4" . "\n"
let rgbhex2=rgbhex2 . "4876ff_RoyalBlue1" . "\n"
let rgbhex2=rgbhex2 . "436eee_RoyalBlue2" . "\n"
let rgbhex2=rgbhex2 . "3a5fcd_RoyalBlue3" . "\n"
let rgbhex2=rgbhex2 . "27408b_RoyalBlue4" . "\n"
let rgbhex2=rgbhex2 . "0000ff_blue1" . "\n"
let rgbhex2=rgbhex2 . "0000ee_blue2" . "\n"
let rgbhex2=rgbhex2 . "0000cd_blue3" . "\n"
let rgbhex2=rgbhex2 . "00008b_blue4" . "\n"
let rgbhex2=rgbhex2 . "1e90ff_DodgerBlue1" . "\n"
let rgbhex2=rgbhex2 . "1c86ee_DodgerBlue2" . "\n"
let rgbhex2=rgbhex2 . "1874cd_DodgerBlue3" . "\n"
let rgbhex2=rgbhex2 . "104e8b_DodgerBlue4" . "\n"
let rgbhex2=rgbhex2 . "63b8ff_SteelBlue1" . "\n"
let rgbhex2=rgbhex2 . "5cacee_SteelBlue2" . "\n"
let rgbhex2=rgbhex2 . "4f94cd_SteelBlue3" . "\n"
let rgbhex2=rgbhex2 . "36648b_SteelBlue4" . "\n"
let rgbhex2=rgbhex2 . "00bfff_DeepSkyBlue1" . "\n"
let rgbhex2=rgbhex2 . "00b2ee_DeepSkyBlue2" . "\n"
let rgbhex2=rgbhex2 . "009acd_DeepSkyBlue3" . "\n"
let rgbhex2=rgbhex2 . "00688b_DeepSkyBlue4" . "\n"
let rgbhex2=rgbhex2 . "87ceff_SkyBlue1" . "\n"
let rgbhex2=rgbhex2 . "7ec0ee_SkyBlue2" . "\n"
let rgbhex2=rgbhex2 . "6ca6cd_SkyBlue3" . "\n"
let rgbhex2=rgbhex2 . "4a708b_SkyBlue4" . "\n"
let rgbhex2=rgbhex2 . "b0e2ff_LightSkyBlue1" . "\n"
let rgbhex2=rgbhex2 . "a4d3ee_LightSkyBlue2" . "\n"
let rgbhex2=rgbhex2 . "8db6cd_LightSkyBlue3" . "\n"
let rgbhex2=rgbhex2 . "607b8b_LightSkyBlue4" . "\n"
let rgbhex2=rgbhex2 . "c6e2ff_SlateGray1" . "\n"
let rgbhex2=rgbhex2 . "b9d3ee_SlateGray2" . "\n"
let rgbhex2=rgbhex2 . "9fb6cd_SlateGray3" . "\n"
let rgbhex2=rgbhex2 . "6c7b8b_SlateGray4" . "\n"
let rgbhex2=rgbhex2 . "cae1ff_LightSteelBlue1" . "\n"
let rgbhex2=rgbhex2 . "bcd2ee_LightSteelBlue2" . "\n"
let rgbhex2=rgbhex2 . "a2b5cd_LightSteelBlue3" . "\n"
let rgbhex2=rgbhex2 . "6e7b8b_LightSteelBlue4" . "\n"
let rgbhex2=rgbhex2 . "bfefff_LightBlue1" . "\n"
let rgbhex2=rgbhex2 . "b2dfee_LightBlue2" . "\n"
let rgbhex2=rgbhex2 . "9ac0cd_LightBlue3" . "\n"
let rgbhex2=rgbhex2 . "68838b_LightBlue4" . "\n"
let rgbhex2=rgbhex2 . "e0ffff_LightCyan1" . "\n"
let rgbhex2=rgbhex2 . "d1eeee_LightCyan2" . "\n"
let rgbhex2=rgbhex2 . "b4cdcd_LightCyan3" . "\n"
let rgbhex2=rgbhex2 . "7a8b8b_LightCyan4" . "\n"
let rgbhex2=rgbhex2 . "bbffff_PaleTurquoise1" . "\n"
let rgbhex2=rgbhex2 . "aeeeee_PaleTurquoise2" . "\n"
let rgbhex2=rgbhex2 . "96cdcd_PaleTurquoise3" . "\n"
let rgbhex2=rgbhex2 . "668b8b_PaleTurquoise4" . "\n"
let rgbhex2=rgbhex2 . "98f5ff_CadetBlue1" . "\n"
let rgbhex2=rgbhex2 . "8ee5ee_CadetBlue2" . "\n"
let rgbhex2=rgbhex2 . "7ac5cd_CadetBlue3" . "\n"
let rgbhex2=rgbhex2 . "53868b_CadetBlue4" . "\n"
let rgbhex2=rgbhex2 . "00f5ff_turquoise1" . "\n"
let rgbhex2=rgbhex2 . "00e5ee_turquoise2" . "\n"
let rgbhex2=rgbhex2 . "00c5cd_turquoise3" . "\n"
let rgbhex2=rgbhex2 . "00868b_turquoise4" . "\n"
let rgbhex2=rgbhex2 . "00ffff_cyan1" . "\n"
let rgbhex2=rgbhex2 . "00eeee_cyan2" . "\n"
let rgbhex2=rgbhex2 . "00cdcd_cyan3" . "\n"
let rgbhex2=rgbhex2 . "008b8b_cyan4" . "\n"
let rgbhex2=rgbhex2 . "97ffff_DarkSlateGray1" . "\n"
let rgbhex2=rgbhex2 . "8deeee_DarkSlateGray2" . "\n"
let rgbhex2=rgbhex2 . "79cdcd_DarkSlateGray3" . "\n"
let rgbhex2=rgbhex2 . "528b8b_DarkSlateGray4" . "\n"
let rgbhex2=rgbhex2 . "7fffd4_aquamarine1" . "\n"
let rgbhex2=rgbhex2 . "76eec6_aquamarine2" . "\n"
let rgbhex2=rgbhex2 . "66cdaa_aquamarine3" . "\n"
let rgbhex2=rgbhex2 . "458b74_aquamarine4" . "\n"
let rgbhex2=rgbhex2 . "c1ffc1_DarkSeaGreen1" . "\n"
let rgbhex2=rgbhex2 . "b4eeb4_DarkSeaGreen2" . "\n"
let rgbhex2=rgbhex2 . "9bcd9b_DarkSeaGreen3" . "\n"
let rgbhex2=rgbhex2 . "698b69_DarkSeaGreen4" . "\n"
let rgbhex2=rgbhex2 . "54ff9f_SeaGreen1" . "\n"
let rgbhex2=rgbhex2 . "4eee94_SeaGreen2" . "\n"
let rgbhex2=rgbhex2 . "43cd80_SeaGreen3" . "\n"
let rgbhex2=rgbhex2 . "2e8b57_SeaGreen4" . "\n"
let rgbhex2=rgbhex2 . "9aff9a_PaleGreen1" . "\n"
let rgbhex2=rgbhex2 . "90ee90_PaleGreen2" . "\n"
let rgbhex2=rgbhex2 . "7ccd7c_PaleGreen3" . "\n"
let rgbhex2=rgbhex2 . "548b54_PaleGreen4" . "\n"
let rgbhex2=rgbhex2 . "00ff7f_SpringGreen1" . "\n"
let rgbhex2=rgbhex2 . "00ee76_SpringGreen2" . "\n"
let rgbhex2=rgbhex2 . "00cd66_SpringGreen3" . "\n"
let rgbhex2=rgbhex2 . "008b45_SpringGreen4" . "\n"
let rgbhex2=rgbhex2 . "00ff00_green1" . "\n"
let rgbhex2=rgbhex2 . "00ee00_green2" . "\n"
let rgbhex2=rgbhex2 . "00cd00_green3" . "\n"
let rgbhex2=rgbhex2 . "008b00_green4" . "\n"
let rgbhex2=rgbhex2 . "7fff00_chartreuse1" . "\n"
let rgbhex2=rgbhex2 . "76ee00_chartreuse2" . "\n"
let rgbhex2=rgbhex2 . "66cd00_chartreuse3" . "\n"
let rgbhex2=rgbhex2 . "458b00_chartreuse4" . "\n"
let rgbhex2=rgbhex2 . "c0ff3e_OliveDrab1" . "\n"
let rgbhex2=rgbhex2 . "b3ee3a_OliveDrab2" . "\n"
let rgbhex2=rgbhex2 . "9acd32_OliveDrab3" . "\n"
let rgbhex2=rgbhex2 . "698b22_OliveDrab4" . "\n"
let rgbhex2=rgbhex2 . "caff70_DarkOliveGreen1" . "\n"
let rgbhex2=rgbhex2 . "bcee68_DarkOliveGreen2" . "\n"
let rgbhex2=rgbhex2 . "a2cd5a_DarkOliveGreen3" . "\n"
let rgbhex2=rgbhex2 . "6e8b3d_DarkOliveGreen4" . "\n"
let rgbhex2=rgbhex2 . "fff68f_khaki1" . "\n"
let rgbhex2=rgbhex2 . "eee685_khaki2" . "\n"
let rgbhex2=rgbhex2 . "cdc673_khaki3" . "\n"
let rgbhex2=rgbhex2 . "8b864e_khaki4" . "\n"
let rgbhex2=rgbhex2 . "ffec8b_LightGoldenrod1" . "\n"
let rgbhex2=rgbhex2 . "eedc82_LightGoldenrod2" . "\n"
let rgbhex2=rgbhex2 . "cdbe70_LightGoldenrod3" . "\n"
let rgbhex2=rgbhex2 . "8b814c_LightGoldenrod4" . "\n"
let rgbhex2=rgbhex2 . "ffffe0_LightYellow1" . "\n"
let rgbhex2=rgbhex2 . "eeeed1_LightYellow2" . "\n"
let rgbhex2=rgbhex2 . "cdcdb4_LightYellow3" . "\n"
let rgbhex2=rgbhex2 . "8b8b7a_LightYellow4" . "\n"
let rgbhex2=rgbhex2 . "ffff00_yellow1" . "\n"
let rgbhex2=rgbhex2 . "eeee00_yellow2" . "\n"
let rgbhex2=rgbhex2 . "cdcd00_yellow3" . "\n"
let rgbhex2=rgbhex2 . "8b8b00_yellow4" . "\n"
let rgbhex2=rgbhex2 . "ffd700_gold1" . "\n"
let rgbhex2=rgbhex2 . "eec900_gold2" . "\n"
let rgbhex2=rgbhex2 . "cdad00_gold3" . "\n"
let rgbhex2=rgbhex2 . "8b7500_gold4" . "\n"
let rgbhex2=rgbhex2 . "ffc125_goldenrod1" . "\n"
let rgbhex2=rgbhex2 . "eeb422_goldenrod2" . "\n"
let rgbhex2=rgbhex2 . "cd9b1d_goldenrod3" . "\n"
let rgbhex2=rgbhex2 . "8b6914_goldenrod4" . "\n"
let rgbhex2=rgbhex2 . "ffb90f_DarkGoldenrod1" . "\n"
let rgbhex2=rgbhex2 . "eead0e_DarkGoldenrod2" . "\n"
let rgbhex2=rgbhex2 . "cd950c_DarkGoldenrod3" . "\n"
let rgbhex2=rgbhex2 . "8b6508_DarkGoldenrod4" . "\n"
let rgbhex2=rgbhex2 . "ffc1c1_RosyBrown1" . "\n"
let rgbhex2=rgbhex2 . "eeb4b4_RosyBrown2" . "\n"
let rgbhex2=rgbhex2 . "cd9b9b_RosyBrown3" . "\n"
let rgbhex2=rgbhex2 . "8b6969_RosyBrown4" . "\n"
let rgbhex2=rgbhex2 . "ff6a6a_IndianRed1" . "\n"
let rgbhex2=rgbhex2 . "ee6363_IndianRed2" . "\n"
let rgbhex2=rgbhex2 . "cd5555_IndianRed3" . "\n"
let rgbhex2=rgbhex2 . "8b3a3a_IndianRed4" . "\n"
let rgbhex2=rgbhex2 . "ff8247_sienna1" . "\n"
let rgbhex2=rgbhex2 . "ee7942_sienna2" . "\n"
let rgbhex2=rgbhex2 . "cd6839_sienna3" . "\n"
let rgbhex2=rgbhex2 . "8b4726_sienna4" . "\n"
let rgbhex2=rgbhex2 . "ffd39b_burlywood1" . "\n"
let rgbhex2=rgbhex2 . "eec591_burlywood2" . "\n"
let rgbhex2=rgbhex2 . "cdaa7d_burlywood3" . "\n"
let rgbhex2=rgbhex2 . "8b7355_burlywood4" . "\n"
let rgbhex2=rgbhex2 . "ffe7ba_wheat1" . "\n"
let rgbhex2=rgbhex2 . "eed8ae_wheat2" . "\n"
let rgbhex2=rgbhex2 . "cdba96_wheat3" . "\n"
let rgbhex2=rgbhex2 . "8b7e66_wheat4" . "\n"
let rgbhex2=rgbhex2 . "ffa54f_tan1" . "\n"
let rgbhex2=rgbhex2 . "ee9a49_tan2" . "\n"
let rgbhex2=rgbhex2 . "cd853f_tan3" . "\n"
let rgbhex2=rgbhex2 . "8b5a2b_tan4" . "\n"
let rgbhex2=rgbhex2 . "ff7f24_chocolate1" . "\n"
let rgbhex2=rgbhex2 . "ee7621_chocolate2" . "\n"
let rgbhex2=rgbhex2 . "cd661d_chocolate3" . "\n"
let rgbhex2=rgbhex2 . "8b4513_chocolate4" . "\n"
let rgbhex2=rgbhex2 . "ff3030_firebrick1" . "\n"
let rgbhex2=rgbhex2 . "ee2c2c_firebrick2" . "\n"
let rgbhex2=rgbhex2 . "cd2626_firebrick3" . "\n"
let rgbhex2=rgbhex2 . "8b1a1a_firebrick4" . "\n"
let rgbhex2=rgbhex2 . "ff4040_brown1" . "\n"
let rgbhex2=rgbhex2 . "ee3b3b_brown2" . "\n"
let rgbhex2=rgbhex2 . "cd3333_brown3" . "\n"
let rgbhex2=rgbhex2 . "8b2323_brown4" . "\n"
let rgbhex2=rgbhex2 . "ff8c69_salmon1" . "\n"
let rgbhex2=rgbhex2 . "ee8262_salmon2" . "\n"
let rgbhex2=rgbhex2 . "cd7054_salmon3" . "\n"
let rgbhex2=rgbhex2 . "8b4c39_salmon4" . "\n"
let rgbhex2=rgbhex2 . "ffa07a_LightSalmon1" . "\n"
let rgbhex2=rgbhex2 . "ee9572_LightSalmon2" . "\n"
let rgbhex2=rgbhex2 . "cd8162_LightSalmon3" . "\n"
let rgbhex2=rgbhex2 . "8b5742_LightSalmon4" . "\n"
let rgbhex2=rgbhex2 . "ffa500_orange1" . "\n"
let rgbhex2=rgbhex2 . "ee9a00_orange2" . "\n"
let rgbhex2=rgbhex2 . "cd8500_orange3" . "\n"
let rgbhex2=rgbhex2 . "8b5a00_orange4" . "\n"
let rgbhex2=rgbhex2 . "ff7f00_DarkOrange1" . "\n"
let rgbhex2=rgbhex2 . "ee7600_DarkOrange2" . "\n"
let rgbhex2=rgbhex2 . "cd6600_DarkOrange3" . "\n"
let rgbhex2=rgbhex2 . "8b4500_DarkOrange4" . "\n"
let rgbhex3=rgbhex3 . "ff7256_coral1" . "\n"
let rgbhex3=rgbhex3 . "ee6a50_coral2" . "\n"
let rgbhex3=rgbhex3 . "cd5b45_coral3" . "\n"
let rgbhex3=rgbhex3 . "8b3e2f_coral4" . "\n"
let rgbhex3=rgbhex3 . "ff6347_tomato1" . "\n"
let rgbhex3=rgbhex3 . "ee5c42_tomato2" . "\n"
let rgbhex3=rgbhex3 . "cd4f39_tomato3" . "\n"
let rgbhex3=rgbhex3 . "8b3626_tomato4" . "\n"
let rgbhex3=rgbhex3 . "ff4500_OrangeRed1" . "\n"
let rgbhex3=rgbhex3 . "ee4000_OrangeRed2" . "\n"
let rgbhex3=rgbhex3 . "cd3700_OrangeRed3" . "\n"
let rgbhex3=rgbhex3 . "8b2500_OrangeRed4" . "\n"
let rgbhex3=rgbhex3 . "ff0000_red1" . "\n"
let rgbhex3=rgbhex3 . "ee0000_red2" . "\n"
let rgbhex3=rgbhex3 . "cd0000_red3" . "\n"
let rgbhex3=rgbhex3 . "8b0000_red4" . "\n"
let rgbhex3=rgbhex3 . "ff1493_DeepPink1" . "\n"
let rgbhex3=rgbhex3 . "ee1289_DeepPink2" . "\n"
let rgbhex3=rgbhex3 . "cd1076_DeepPink3" . "\n"
let rgbhex3=rgbhex3 . "8b0a50_DeepPink4" . "\n"
let rgbhex3=rgbhex3 . "ff6eb4_HotPink1" . "\n"
let rgbhex3=rgbhex3 . "ee6aa7_HotPink2" . "\n"
let rgbhex3=rgbhex3 . "cd6090_HotPink3" . "\n"
let rgbhex3=rgbhex3 . "8b3a62_HotPink4" . "\n"
let rgbhex3=rgbhex3 . "ffb5c5_pink1" . "\n"
let rgbhex3=rgbhex3 . "eea9b8_pink2" . "\n"
let rgbhex3=rgbhex3 . "cd919e_pink3" . "\n"
let rgbhex3=rgbhex3 . "8b636c_pink4" . "\n"
let rgbhex3=rgbhex3 . "ffaeb9_LightPink1" . "\n"
let rgbhex3=rgbhex3 . "eea2ad_LightPink2" . "\n"
let rgbhex3=rgbhex3 . "cd8c95_LightPink3" . "\n"
let rgbhex3=rgbhex3 . "8b5f65_LightPink4" . "\n"
let rgbhex3=rgbhex3 . "ff82ab_PaleVioletRed1" . "\n"
let rgbhex3=rgbhex3 . "ee799f_PaleVioletRed2" . "\n"
let rgbhex3=rgbhex3 . "cd6889_PaleVioletRed3" . "\n"
let rgbhex3=rgbhex3 . "8b475d_PaleVioletRed4" . "\n"
let rgbhex3=rgbhex3 . "ff34b3_maroon1" . "\n"
let rgbhex3=rgbhex3 . "ee30a7_maroon2" . "\n"
let rgbhex3=rgbhex3 . "cd2990_maroon3" . "\n"
let rgbhex3=rgbhex3 . "8b1c62_maroon4" . "\n"
let rgbhex3=rgbhex3 . "ff3e96_VioletRed1" . "\n"
let rgbhex3=rgbhex3 . "ee3a8c_VioletRed2" . "\n"
let rgbhex3=rgbhex3 . "cd3278_VioletRed3" . "\n"
let rgbhex3=rgbhex3 . "8b2252_VioletRed4" . "\n"
let rgbhex3=rgbhex3 . "ff00ff_magenta1" . "\n"
let rgbhex3=rgbhex3 . "ee00ee_magenta2" . "\n"
let rgbhex3=rgbhex3 . "cd00cd_magenta3" . "\n"
let rgbhex3=rgbhex3 . "8b008b_magenta4" . "\n"
let rgbhex3=rgbhex3 . "ff83fa_orchid1" . "\n"
let rgbhex3=rgbhex3 . "ee7ae9_orchid2" . "\n"
let rgbhex3=rgbhex3 . "cd69c9_orchid3" . "\n"
let rgbhex3=rgbhex3 . "8b4789_orchid4" . "\n"
let rgbhex3=rgbhex3 . "ffbbff_plum1" . "\n"
let rgbhex3=rgbhex3 . "eeaeee_plum2" . "\n"
let rgbhex3=rgbhex3 . "cd96cd_plum3" . "\n"
let rgbhex3=rgbhex3 . "8b668b_plum4" . "\n"
let rgbhex3=rgbhex3 . "e066ff_MediumOrchid1" . "\n"
let rgbhex3=rgbhex3 . "d15fee_MediumOrchid2" . "\n"
let rgbhex3=rgbhex3 . "b452cd_MediumOrchid3" . "\n"
let rgbhex3=rgbhex3 . "7a378b_MediumOrchid4" . "\n"
let rgbhex3=rgbhex3 . "bf3eff_DarkOrchid1" . "\n"
let rgbhex3=rgbhex3 . "b23aee_DarkOrchid2" . "\n"
let rgbhex3=rgbhex3 . "9a32cd_DarkOrchid3" . "\n"
let rgbhex3=rgbhex3 . "68228b_DarkOrchid4" . "\n"
let rgbhex3=rgbhex3 . "9b30ff_purple1" . "\n"
let rgbhex3=rgbhex3 . "912cee_purple2" . "\n"
let rgbhex3=rgbhex3 . "7d26cd_purple3" . "\n"
let rgbhex3=rgbhex3 . "551a8b_purple4" . "\n"
let rgbhex3=rgbhex3 . "ab82ff_MediumPurple1" . "\n"
let rgbhex3=rgbhex3 . "9f79ee_MediumPurple2" . "\n"
let rgbhex3=rgbhex3 . "8968cd_MediumPurple3" . "\n"
let rgbhex3=rgbhex3 . "5d478b_MediumPurple4" . "\n"
let rgbhex3=rgbhex3 . "ffe1ff_thistle1" . "\n"
let rgbhex3=rgbhex3 . "eed2ee_thistle2" . "\n"
let rgbhex3=rgbhex3 . "cdb5cd_thistle3" . "\n"
let rgbhex3=rgbhex3 . "8b7b8b_thistle4" . "\n"
let rgbhex3=rgbhex3 . "000000_gray0" . "\n"
let rgbhex3=rgbhex3 . "030303_gray1" . "\n"
let rgbhex3=rgbhex3 . "050505_gray2" . "\n"
let rgbhex3=rgbhex3 . "080808_gray3" . "\n"
let rgbhex3=rgbhex3 . "0a0a0a_gray4" . "\n"
let rgbhex3=rgbhex3 . "0d0d0d_gray5" . "\n"
let rgbhex3=rgbhex3 . "0f0f0f_gray6" . "\n"
let rgbhex3=rgbhex3 . "121212_gray7" . "\n"
let rgbhex3=rgbhex3 . "141414_gray8" . "\n"
let rgbhex3=rgbhex3 . "171717_gray9" . "\n"
let rgbhex3=rgbhex3 . "1a1a1a_gray10" . "\n"
let rgbhex3=rgbhex3 . "1c1c1c_gray11" . "\n"
let rgbhex3=rgbhex3 . "1f1f1f_gray12" . "\n"
let rgbhex3=rgbhex3 . "212121_gray13" . "\n"
let rgbhex3=rgbhex3 . "242424_gray14" . "\n"
let rgbhex3=rgbhex3 . "262626_gray15" . "\n"
let rgbhex3=rgbhex3 . "292929_gray16" . "\n"
let rgbhex3=rgbhex3 . "2b2b2b_gray17" . "\n"
let rgbhex3=rgbhex3 . "2e2e2e_gray18" . "\n"
let rgbhex3=rgbhex3 . "303030_gray19" . "\n"
let rgbhex3=rgbhex3 . "333333_gray20" . "\n"
let rgbhex3=rgbhex3 . "363636_gray21" . "\n"
let rgbhex3=rgbhex3 . "383838_gray22" . "\n"
let rgbhex3=rgbhex3 . "3b3b3b_gray23" . "\n"
let rgbhex3=rgbhex3 . "3d3d3d_gray24" . "\n"
let rgbhex3=rgbhex3 . "404040_gray25" . "\n"
let rgbhex3=rgbhex3 . "424242_gray26" . "\n"
let rgbhex3=rgbhex3 . "454545_gray27" . "\n"
let rgbhex3=rgbhex3 . "474747_gray28" . "\n"
let rgbhex3=rgbhex3 . "4a4a4a_gray29" . "\n"
let rgbhex3=rgbhex3 . "4d4d4d_gray30" . "\n"
let rgbhex3=rgbhex3 . "4f4f4f_gray31" . "\n"
let rgbhex3=rgbhex3 . "525252_gray32" . "\n"
let rgbhex3=rgbhex3 . "545454_gray33" . "\n"
let rgbhex3=rgbhex3 . "575757_gray34" . "\n"
let rgbhex3=rgbhex3 . "595959_gray35" . "\n"
let rgbhex3=rgbhex3 . "5c5c5c_gray36" . "\n"
let rgbhex3=rgbhex3 . "5e5e5e_gray37" . "\n"
let rgbhex3=rgbhex3 . "616161_gray38" . "\n"
let rgbhex3=rgbhex3 . "636363_gray39" . "\n"
let rgbhex3=rgbhex3 . "666666_gray40" . "\n"
let rgbhex3=rgbhex3 . "696969_gray41" . "\n"
let rgbhex3=rgbhex3 . "6b6b6b_gray42" . "\n"
let rgbhex3=rgbhex3 . "6e6e6e_gray43" . "\n"
let rgbhex3=rgbhex3 . "707070_gray44" . "\n"
let rgbhex3=rgbhex3 . "737373_gray45" . "\n"
let rgbhex3=rgbhex3 . "757575_gray46" . "\n"
let rgbhex3=rgbhex3 . "787878_gray47" . "\n"
let rgbhex3=rgbhex3 . "7a7a7a_gray48" . "\n"
let rgbhex3=rgbhex3 . "7d7d7d_gray49" . "\n"
let rgbhex3=rgbhex3 . "7f7f7f_gray50" . "\n"
let rgbhex3=rgbhex3 . "828282_gray51" . "\n"
let rgbhex3=rgbhex3 . "858585_gray52" . "\n"
let rgbhex3=rgbhex3 . "878787_gray53" . "\n"
let rgbhex3=rgbhex3 . "8a8a8a_gray54" . "\n"
let rgbhex3=rgbhex3 . "8c8c8c_gray55" . "\n"
let rgbhex3=rgbhex3 . "8f8f8f_gray56" . "\n"
let rgbhex3=rgbhex3 . "919191_gray57" . "\n"
let rgbhex3=rgbhex3 . "949494_gray58" . "\n"
let rgbhex3=rgbhex3 . "969696_gray59" . "\n"
let rgbhex3=rgbhex3 . "999999_gray60" . "\n"
let rgbhex3=rgbhex3 . "9c9c9c_gray61" . "\n"
let rgbhex3=rgbhex3 . "9e9e9e_gray62" . "\n"
let rgbhex3=rgbhex3 . "a1a1a1_gray63" . "\n"
let rgbhex3=rgbhex3 . "a3a3a3_gray64" . "\n"
let rgbhex3=rgbhex3 . "a6a6a6_gray65" . "\n"
let rgbhex3=rgbhex3 . "a8a8a8_gray66" . "\n"
let rgbhex3=rgbhex3 . "ababab_gray67" . "\n"
let rgbhex3=rgbhex3 . "adadad_gray68" . "\n"
let rgbhex3=rgbhex3 . "b0b0b0_gray69" . "\n"
let rgbhex3=rgbhex3 . "b3b3b3_gray70" . "\n"
let rgbhex3=rgbhex3 . "b5b5b5_gray71" . "\n"
let rgbhex3=rgbhex3 . "b8b8b8_gray72" . "\n"
let rgbhex3=rgbhex3 . "bababa_gray73" . "\n"
let rgbhex3=rgbhex3 . "bdbdbd_gray74" . "\n"
let rgbhex3=rgbhex3 . "bfbfbf_gray75" . "\n"
let rgbhex3=rgbhex3 . "c2c2c2_gray76" . "\n"
let rgbhex3=rgbhex3 . "c4c4c4_gray77" . "\n"
let rgbhex3=rgbhex3 . "c7c7c7_gray78" . "\n"
let rgbhex3=rgbhex3 . "c9c9c9_gray79" . "\n"
let rgbhex3=rgbhex3 . "cccccc_gray80" . "\n"
let rgbhex3=rgbhex3 . "cfcfcf_gray81" . "\n"
let rgbhex3=rgbhex3 . "d1d1d1_gray82" . "\n"
let rgbhex3=rgbhex3 . "d4d4d4_gray83" . "\n"
let rgbhex3=rgbhex3 . "d6d6d6_gray84" . "\n"
let rgbhex3=rgbhex3 . "d9d9d9_gray85" . "\n"
let rgbhex3=rgbhex3 . "dbdbdb_gray86" . "\n"
let rgbhex3=rgbhex3 . "dedede_gray87" . "\n"
let rgbhex3=rgbhex3 . "e0e0e0_gray88" . "\n"
let rgbhex3=rgbhex3 . "e3e3e3_gray89" . "\n"
let rgbhex3=rgbhex3 . "e5e5e5_gray90" . "\n"
let rgbhex3=rgbhex3 . "e8e8e8_gray91" . "\n"
let rgbhex3=rgbhex3 . "ebebeb_gray92" . "\n"
let rgbhex3=rgbhex3 . "ededed_gray93" . "\n"
let rgbhex3=rgbhex3 . "f0f0f0_gray94" . "\n"
let rgbhex3=rgbhex3 . "f2f2f2_gray95" . "\n"
let rgbhex3=rgbhex3 . "f5f5f5_gray96" . "\n"
let rgbhex3=rgbhex3 . "f7f7f7_gray97" . "\n"
let rgbhex3=rgbhex3 . "fafafa_gray98" . "\n"
let rgbhex3=rgbhex3 . "fcfcfc_gray99" . "\n"
let rgbhex3=rgbhex3 . "ffffff_gray100" . "\n"
let rgbhex3=rgbhex3 . "a9a9a9_DarkGray" . "\n"
let rgbhex3=rgbhex3 . "00008b_DarkBlue" . "\n"
let rgbhex3=rgbhex3 . "008b8b_DarkCyan" . "\n"
let rgbhex3=rgbhex3 . "8b008b_DarkMagenta" . "\n"
let rgbhex3=rgbhex3 . "8b0000_DarkRed" . "\n"
let rgbhex3=rgbhex3 . "90ee90_LightGreen" . "\n"
let cterm1=cterm1 . "cterm_0_gui_000000" . "\n"
let cterm1=cterm1 . "cterm_1_gui_ce0000" . "\n"
let cterm1=cterm1 . "cterm_2_gui_00cb00" . "\n"
let cterm1=cterm1 . "cterm_3_gui_cecb00" . "\n"
let cterm1=cterm1 . "cterm_4_gui_0000ef" . "\n"
let cterm1=cterm1 . "cterm_5_gui_ce00ce" . "\n"
let cterm1=cterm1 . "cterm_6_gui_00cbce" . "\n"
let cterm1=cterm1 . "cterm_7_gui_e7e3e7" . "\n"
let cterm1=cterm1 . "cterm_8_gui_7b7d7b" . "\n"
let cterm1=cterm1 . "cterm_9_gui_ff0000" . "\n"
let cterm1=cterm1 . "cterm_10_gui_00ff00" . "\n"
let cterm1=cterm1 . "cterm_11_gui_ffff00" . "\n"
let cterm1=cterm1 . "cterm_12_gui_5a5dff" . "\n"
let cterm1=cterm1 . "cterm_13_gui_ff00ff" . "\n"
let cterm1=cterm1 . "cterm_14_gui_00ffff" . "\n"
let cterm1=cterm1 . "cterm_15_gui_ffffff" . "\n"
let cterm1=cterm1 . "cterm_16_gui_000000" . "\n"
let cterm1=cterm1 . "cterm_17_gui_00005f" . "\n"
let cterm1=cterm1 . "cterm_18_gui_000087" . "\n"
let cterm1=cterm1 . "cterm_19_gui_0000af" . "\n"
let cterm1=cterm1 . "cterm_20_gui_0000d7" . "\n"
let cterm1=cterm1 . "cterm_21_gui_0000ff" . "\n"
let cterm1=cterm1 . "cterm_22_gui_005f00" . "\n"
let cterm1=cterm1 . "cterm_23_gui_005f5f" . "\n"
let cterm1=cterm1 . "cterm_24_gui_005f87" . "\n"
let cterm1=cterm1 . "cterm_25_gui_005faf" . "\n"
let cterm1=cterm1 . "cterm_26_gui_005fd7" . "\n"
let cterm1=cterm1 . "cterm_27_gui_005fff" . "\n"
let cterm1=cterm1 . "cterm_28_gui_008700" . "\n"
let cterm1=cterm1 . "cterm_29_gui_00875f" . "\n"
let cterm1=cterm1 . "cterm_30_gui_008787" . "\n"
let cterm1=cterm1 . "cterm_31_gui_0087af" . "\n"
let cterm1=cterm1 . "cterm_32_gui_0087d7" . "\n"
let cterm1=cterm1 . "cterm_33_gui_0087ff" . "\n"
let cterm1=cterm1 . "cterm_34_gui_00af00" . "\n"
let cterm1=cterm1 . "cterm_35_gui_00af5f" . "\n"
let cterm1=cterm1 . "cterm_36_gui_00af87" . "\n"
let cterm1=cterm1 . "cterm_37_gui_00afaf" . "\n"
let cterm1=cterm1 . "cterm_38_gui_00afd7" . "\n"
let cterm1=cterm1 . "cterm_39_gui_00afff" . "\n"
let cterm1=cterm1 . "cterm_40_gui_00d700" . "\n"
let cterm1=cterm1 . "cterm_41_gui_00d75f" . "\n"
let cterm1=cterm1 . "cterm_42_gui_00d787" . "\n"
let cterm1=cterm1 . "cterm_43_gui_00d7af" . "\n"
let cterm1=cterm1 . "cterm_44_gui_00d7d7" . "\n"
let cterm1=cterm1 . "cterm_45_gui_00d7ff" . "\n"
let cterm1=cterm1 . "cterm_46_gui_00ff00" . "\n"
let cterm1=cterm1 . "cterm_47_gui_00ff5f" . "\n"
let cterm1=cterm1 . "cterm_48_gui_00ff87" . "\n"
let cterm1=cterm1 . "cterm_49_gui_00ffaf" . "\n"
let cterm1=cterm1 . "cterm_50_gui_00ffd7" . "\n"
let cterm1=cterm1 . "cterm_51_gui_00ffff" . "\n"
let cterm1=cterm1 . "cterm_52_gui_5f0000" . "\n"
let cterm1=cterm1 . "cterm_53_gui_5f005f" . "\n"
let cterm1=cterm1 . "cterm_54_gui_5f0087" . "\n"
let cterm1=cterm1 . "cterm_55_gui_5f00af" . "\n"
let cterm1=cterm1 . "cterm_56_gui_5f00d7" . "\n"
let cterm1=cterm1 . "cterm_57_gui_5f00ff" . "\n"
let cterm1=cterm1 . "cterm_58_gui_5f5f00" . "\n"
let cterm1=cterm1 . "cterm_59_gui_5f5f5f" . "\n"
let cterm1=cterm1 . "cterm_60_gui_5f5f87" . "\n"
let cterm1=cterm1 . "cterm_61_gui_5f5faf" . "\n"
let cterm1=cterm1 . "cterm_62_gui_5f5fd7" . "\n"
let cterm1=cterm1 . "cterm_64_gui_5f8700" . "\n"
let cterm1=cterm1 . "cterm_65_gui_5f875f" . "\n"
let cterm1=cterm1 . "cterm_66_gui_5f8787" . "\n"
let cterm1=cterm1 . "cterm_63_gui_5f5fff" . "\n"
let cterm1=cterm1 . "cterm_67_gui_5f87af" . "\n"
let cterm1=cterm1 . "cterm_68_gui_5f87d7" . "\n"
let cterm1=cterm1 . "cterm_69_gui_5f87ff" . "\n"
let cterm1=cterm1 . "cterm_70_gui_5faf00" . "\n"
let cterm1=cterm1 . "cterm_71_gui_5faf5f" . "\n"
let cterm1=cterm1 . "cterm_72_gui_5faf87" . "\n"
let cterm1=cterm1 . "cterm_73_gui_5fafaf" . "\n"
let cterm1=cterm1 . "cterm_74_gui_5fafd7" . "\n"
let cterm1=cterm1 . "cterm_75_gui_5fafff" . "\n"
let cterm1=cterm1 . "cterm_76_gui_5fd700" . "\n"
let cterm1=cterm1 . "cterm_77_gui_5fd75f" . "\n"
let cterm1=cterm1 . "cterm_78_gui_5fd787" . "\n"
let cterm1=cterm1 . "cterm_79_gui_5fd7af" . "\n"
let cterm1=cterm1 . "cterm_80_gui_5fd7d7" . "\n"
let cterm1=cterm1 . "cterm_81_gui_5fd7ff" . "\n"
let cterm1=cterm1 . "cterm_82_gui_5fff00" . "\n"
let cterm1=cterm1 . "cterm_83_gui_5fff5f" . "\n"
let cterm1=cterm1 . "cterm_84_gui_5fff87" . "\n"
let cterm1=cterm1 . "cterm_85_gui_5fffaf" . "\n"
let cterm1=cterm1 . "cterm_86_gui_5fffd7" . "\n"
let cterm1=cterm1 . "cterm_87_gui_5fffff" . "\n"
let cterm1=cterm1 . "cterm_88_gui_870000" . "\n"
let cterm1=cterm1 . "cterm_89_gui_87005f" . "\n"
let cterm1=cterm1 . "cterm_90_gui_870087" . "\n"
let cterm1=cterm1 . "cterm_91_gui_8700af" . "\n"
let cterm1=cterm1 . "cterm_92_gui_8700d7" . "\n"
let cterm1=cterm1 . "cterm_93_gui_8700ff" . "\n"
let cterm1=cterm1 . "cterm_94_gui_875f00" . "\n"
let cterm1=cterm1 . "cterm_95_gui_875f5f" . "\n"
let cterm1=cterm1 . "cterm_96_gui_875f87" . "\n"
let cterm1=cterm1 . "cterm_97_gui_875faf" . "\n"
let cterm1=cterm1 . "cterm_98_gui_875fd7" . "\n"
let cterm1=cterm1 . "cterm_99_gui_875fff" . "\n"
let cterm1=cterm1 . "cterm_100_gui_878700" . "\n"
let cterm1=cterm1 . "cterm_101_gui_87875f" . "\n"
let cterm1=cterm1 . "cterm_102_gui_878787" . "\n"
let cterm1=cterm1 . "cterm_103_gui_8787af" . "\n"
let cterm1=cterm1 . "cterm_104_gui_8787d7" . "\n"
let cterm1=cterm1 . "cterm_105_gui_8787ff" . "\n"
let cterm1=cterm1 . "cterm_106_gui_87af00" . "\n"
let cterm1=cterm1 . "cterm_107_gui_87af5f" . "\n"
let cterm1=cterm1 . "cterm_108_gui_87af87" . "\n"
let cterm1=cterm1 . "cterm_109_gui_87afaf" . "\n"
let cterm1=cterm1 . "cterm_110_gui_87afd7" . "\n"
let cterm1=cterm1 . "cterm_111_gui_87afff" . "\n"
let cterm1=cterm1 . "cterm_112_gui_87d700" . "\n"
let cterm1=cterm1 . "cterm_113_gui_87d75f" . "\n"
let cterm1=cterm1 . "cterm_114_gui_87d787" . "\n"
let cterm1=cterm1 . "cterm_115_gui_87d7af" . "\n"
let cterm1=cterm1 . "cterm_116_gui_87d7d7" . "\n"
let cterm1=cterm1 . "cterm_117_gui_87d7ff" . "\n"
let cterm1=cterm1 . "cterm_118_gui_87ff00" . "\n"
let cterm1=cterm1 . "cterm_119_gui_87ff5f" . "\n"
let cterm1=cterm1 . "cterm_120_gui_87ff87" . "\n"
let cterm1=cterm1 . "cterm_121_gui_87ffaf" . "\n"
let cterm1=cterm1 . "cterm_122_gui_87ffd7" . "\n"
let cterm1=cterm1 . "cterm_123_gui_87ffff" . "\n"
let cterm1=cterm1 . "cterm_124_gui_af0000" . "\n"
let cterm1=cterm1 . "cterm_125_gui_af005f" . "\n"
let cterm1=cterm1 . "cterm_126_gui_af0087" . "\n"
let cterm1=cterm1 . "cterm_127_gui_af00af" . "\n"
let cterm1=cterm1 . "cterm_128_gui_af00d7" . "\n"
let cterm2=cterm2 . "cterm_129_gui_af00ff" . "\n"
let cterm2=cterm2 . "cterm_130_gui_af5f00" . "\n"
let cterm2=cterm2 . "cterm_131_gui_af5f5f" . "\n"
let cterm2=cterm2 . "cterm_132_gui_af5f87" . "\n"
let cterm2=cterm2 . "cterm_133_gui_af5faf" . "\n"
let cterm2=cterm2 . "cterm_134_gui_af5fd7" . "\n"
let cterm2=cterm2 . "cterm_135_gui_af5fff" . "\n"
let cterm2=cterm2 . "cterm_136_gui_af8700" . "\n"
let cterm2=cterm2 . "cterm_137_gui_af875f" . "\n"
let cterm2=cterm2 . "cterm_138_gui_af8787" . "\n"
let cterm2=cterm2 . "cterm_139_gui_af87af" . "\n"
let cterm2=cterm2 . "cterm_140_gui_af87d7" . "\n"
let cterm2=cterm2 . "cterm_141_gui_af87ff" . "\n"
let cterm2=cterm2 . "cterm_142_gui_afaf00" . "\n"
let cterm2=cterm2 . "cterm_143_gui_afaf5f" . "\n"
let cterm2=cterm2 . "cterm_144_gui_afaf87" . "\n"
let cterm2=cterm2 . "cterm_145_gui_afafaf" . "\n"
let cterm2=cterm2 . "cterm_146_gui_afafd7" . "\n"
let cterm2=cterm2 . "cterm_147_gui_afafff" . "\n"
let cterm2=cterm2 . "cterm_148_gui_afd700" . "\n"
let cterm2=cterm2 . "cterm_149_gui_afd75f" . "\n"
let cterm2=cterm2 . "cterm_150_gui_afd787" . "\n"
let cterm2=cterm2 . "cterm_151_gui_afd7af" . "\n"
let cterm2=cterm2 . "cterm_152_gui_afd7d7" . "\n"
let cterm2=cterm2 . "cterm_153_gui_afd7ff" . "\n"
let cterm2=cterm2 . "cterm_154_gui_afff00" . "\n"
let cterm2=cterm2 . "cterm_155_gui_afff5f" . "\n"
let cterm2=cterm2 . "cterm_156_gui_afff87" . "\n"
let cterm2=cterm2 . "cterm_157_gui_afffaf" . "\n"
let cterm2=cterm2 . "cterm_158_gui_afffd7" . "\n"
let cterm2=cterm2 . "cterm_159_gui_afffff" . "\n"
let cterm2=cterm2 . "cterm_160_gui_d70000" . "\n"
let cterm2=cterm2 . "cterm_161_gui_d7005f" . "\n"
let cterm2=cterm2 . "cterm_162_gui_d70087" . "\n"
let cterm2=cterm2 . "cterm_163_gui_d700af" . "\n"
let cterm2=cterm2 . "cterm_164_gui_d700d7" . "\n"
let cterm2=cterm2 . "cterm_165_gui_d700ff" . "\n"
let cterm2=cterm2 . "cterm_166_gui_d75f00" . "\n"
let cterm2=cterm2 . "cterm_167_gui_d75f5f" . "\n"
let cterm2=cterm2 . "cterm_168_gui_d75f87" . "\n"
let cterm2=cterm2 . "cterm_169_gui_d75faf" . "\n"
let cterm2=cterm2 . "cterm_170_gui_d75fd7" . "\n"
let cterm2=cterm2 . "cterm_171_gui_d75fff" . "\n"
let cterm2=cterm2 . "cterm_172_gui_d78700" . "\n"
let cterm2=cterm2 . "cterm_173_gui_d7875f" . "\n"
let cterm2=cterm2 . "cterm_174_gui_d78787" . "\n"
let cterm2=cterm2 . "cterm_175_gui_d787af" . "\n"
let cterm2=cterm2 . "cterm_176_gui_d787d7" . "\n"
let cterm2=cterm2 . "cterm_177_gui_d787ff" . "\n"
let cterm2=cterm2 . "cterm_178_gui_d7af00" . "\n"
let cterm2=cterm2 . "cterm_179_gui_d7af5f" . "\n"
let cterm2=cterm2 . "cterm_180_gui_d7af87" . "\n"
let cterm2=cterm2 . "cterm_181_gui_d7afaf" . "\n"
let cterm2=cterm2 . "cterm_182_gui_d7afd7" . "\n"
let cterm2=cterm2 . "cterm_183_gui_d7afff" . "\n"
let cterm2=cterm2 . "cterm_184_gui_d7d700" . "\n"
let cterm2=cterm2 . "cterm_185_gui_d7d75f" . "\n"
let cterm2=cterm2 . "cterm_186_gui_d7d787" . "\n"
let cterm2=cterm2 . "cterm_187_gui_d7d7af" . "\n"
let cterm2=cterm2 . "cterm_188_gui_d7d7d7" . "\n"
let cterm2=cterm2 . "cterm_189_gui_d7d7ff" . "\n"
let cterm2=cterm2 . "cterm_190_gui_d7ff00" . "\n"
let cterm2=cterm2 . "cterm_191_gui_d7ff5f" . "\n"
let cterm2=cterm2 . "cterm_192_gui_d7ff87" . "\n"
let cterm2=cterm2 . "cterm_193_gui_d7ffaf" . "\n"
let cterm2=cterm2 . "cterm_194_gui_d7ffd7" . "\n"
let cterm2=cterm2 . "cterm_195_gui_d7ffff" . "\n"
let cterm2=cterm2 . "cterm_196_gui_ff0000" . "\n"
let cterm2=cterm2 . "cterm_197_gui_ff005f" . "\n"
let cterm2=cterm2 . "cterm_198_gui_ff0087" . "\n"
let cterm2=cterm2 . "cterm_199_gui_ff00af" . "\n"
let cterm2=cterm2 . "cterm_200_gui_ff00d7" . "\n"
let cterm2=cterm2 . "cterm_201_gui_ff00ff" . "\n"
let cterm2=cterm2 . "cterm_202_gui_ff5f00" . "\n"
let cterm2=cterm2 . "cterm_203_gui_ff5f5f" . "\n"
let cterm2=cterm2 . "cterm_204_gui_ff5f87" . "\n"
let cterm2=cterm2 . "cterm_205_gui_ff5faf" . "\n"
let cterm2=cterm2 . "cterm_206_gui_ff5fd7" . "\n"
let cterm2=cterm2 . "cterm_207_gui_ff5fff" . "\n"
let cterm2=cterm2 . "cterm_208_gui_ff8700" . "\n"
let cterm2=cterm2 . "cterm_209_gui_ff875f" . "\n"
let cterm2=cterm2 . "cterm_210_gui_ff8787" . "\n"
let cterm2=cterm2 . "cterm_211_gui_ff87af" . "\n"
let cterm2=cterm2 . "cterm_212_gui_ff87d7" . "\n"
let cterm2=cterm2 . "cterm_213_gui_ff87ff" . "\n"
let cterm2=cterm2 . "cterm_214_gui_ffaf00" . "\n"
let cterm2=cterm2 . "cterm_215_gui_ffaf5f" . "\n"
let cterm2=cterm2 . "cterm_216_gui_ffaf87" . "\n"
let cterm2=cterm2 . "cterm_217_gui_ffafaf" . "\n"
let cterm2=cterm2 . "cterm_218_gui_ffafd7" . "\n"
let cterm2=cterm2 . "cterm_219_gui_ffafff" . "\n"
let cterm2=cterm2 . "cterm_220_gui_ffd700" . "\n"
let cterm2=cterm2 . "cterm_221_gui_ffd75f" . "\n"
let cterm2=cterm2 . "cterm_222_gui_ffd787" . "\n"
let cterm2=cterm2 . "cterm_223_gui_ffd7af" . "\n"
let cterm2=cterm2 . "cterm_224_gui_ffd7d7" . "\n"
let cterm2=cterm2 . "cterm_225_gui_ffd7ff" . "\n"
let cterm2=cterm2 . "cterm_226_gui_ffff00" . "\n"
let cterm2=cterm2 . "cterm_227_gui_ffff5f" . "\n"
let cterm2=cterm2 . "cterm_228_gui_ffff87" . "\n"
let cterm2=cterm2 . "cterm_229_gui_ffffaf" . "\n"
let cterm2=cterm2 . "cterm_230_gui_ffffd7" . "\n"
let cterm2=cterm2 . "cterm_231_gui_ffffff" . "\n"
let cterm2=cterm2 . "cterm_232_gui_080808" . "\n"
let cterm2=cterm2 . "cterm_233_gui_121212" . "\n"
let cterm2=cterm2 . "cterm_234_gui_1c1c1c" . "\n"
let cterm2=cterm2 . "cterm_235_gui_262626" . "\n"
let cterm2=cterm2 . "cterm_236_gui_303030" . "\n"
let cterm2=cterm2 . "cterm_237_gui_3a3a3a" . "\n"
let cterm2=cterm2 . "cterm_238_gui_444444" . "\n"
let cterm2=cterm2 . "cterm_239_gui_4e4e4e" . "\n"
let cterm2=cterm2 . "cterm_240_gui_585858" . "\n"
let cterm2=cterm2 . "cterm_241_gui_626262" . "\n"
let cterm2=cterm2 . "cterm_242_gui_6c6c6c" . "\n"
let cterm2=cterm2 . "cterm_243_gui_767676" . "\n"
let cterm2=cterm2 . "cterm_244_gui_808080" . "\n"
let cterm2=cterm2 . "cterm_245_gui_8a8a8a" . "\n"
let cterm2=cterm2 . "cterm_246_gui_949494" . "\n"
let cterm2=cterm2 . "cterm_247_gui_9e9e9e" . "\n"
let cterm2=cterm2 . "cterm_248_gui_a8a8a8" . "\n"
let cterm2=cterm2 . "cterm_249_gui_b2b2b2" . "\n"
let cterm2=cterm2 . "cterm_250_gui_bcbcbc" . "\n"
let cterm2=cterm2 . "cterm_251_gui_c6c6c6" . "\n"
let cterm2=cterm2 . "cterm_252_gui_d0d0d0" . "\n"
let cterm2=cterm2 . "cterm_253_gui_dadada" . "\n"
let cterm2=cterm2 . "cterm_254_gui_e4e4e4" . "\n"
let cterm2=cterm2 . "cterm_255_gui_eeeeee" . "\n"

let rgbsort=""
let rgbsort=rgbsort . "000000_black" . "\n"
let rgbsort=rgbsort . "000000_gray0" . "\n"
let rgbsort=rgbsort . "cterm_0_gui_000000" . "\n"
let rgbsort=rgbsort . "cterm_16_gui_000000" . "\n"
let rgbsort=rgbsort . "030303_gray1" . "\n"
let rgbsort=rgbsort . "050505_gray2" . "\n"
let rgbsort=rgbsort . "080808_gray3" . "\n"
let rgbsort=rgbsort . "cterm_232_gui_080808" . "\n"
let rgbsort=rgbsort . "0a0a0a_gray4" . "\n"
let rgbsort=rgbsort . "0d0d0d_gray5" . "\n"
let rgbsort=rgbsort . "0f0f0f_gray6" . "\n"
let rgbsort=rgbsort . "121212_gray7" . "\n"
let rgbsort=rgbsort . "cterm_233_gui_121212" . "\n"
let rgbsort=rgbsort . "141414_gray8" . "\n"
let rgbsort=rgbsort . "171717_gray9" . "\n"
let rgbsort=rgbsort . "1a1a1a_gray10" . "\n"
let rgbsort=rgbsort . "1c1c1c_gray11" . "\n"
let rgbsort=rgbsort . "cterm_234_gui_1c1c1c" . "\n"
let rgbsort=rgbsort . "1f1f1f_gray12" . "\n"
let rgbsort=rgbsort . "212121_gray13" . "\n"
let rgbsort=rgbsort . "242424_gray14" . "\n"
let rgbsort=rgbsort . "262626_gray15" . "\n"
let rgbsort=rgbsort . "cterm_235_gui_262626" . "\n"
let rgbsort=rgbsort . "292929_gray16" . "\n"
let rgbsort=rgbsort . "2b2b2b_gray17" . "\n"
let rgbsort=rgbsort . "2e2e2e_gray18" . "\n"
let rgbsort=rgbsort . "303030_gray19" . "\n"
let rgbsort=rgbsort . "cterm_236_gui_303030" . "\n"
let rgbsort=rgbsort . "333333_gray20" . "\n"
let rgbsort=rgbsort . "363636_gray21" . "\n"
let rgbsort=rgbsort . "383838_gray22" . "\n"
let rgbsort=rgbsort . "cterm_237_gui_3a3a3a" . "\n"
let rgbsort=rgbsort . "3b3b3b_gray23" . "\n"
let rgbsort=rgbsort . "3d3d3d_gray24" . "\n"
let rgbsort=rgbsort . "404040_gray25" . "\n"
let rgbsort=rgbsort . "424242_gray26" . "\n"
let rgbsort=rgbsort . "cterm_238_gui_444444" . "\n"
let rgbsort=rgbsort . "454545_gray27" . "\n"
let rgbsort=rgbsort . "474747_gray28" . "\n"
let rgbsort=rgbsort . "4a4a4a_gray29" . "\n"
let rgbsort=rgbsort . "4d4d4d_gray30" . "\n"
let rgbsort=rgbsort . "cterm_239_gui_4e4e4e" . "\n"
let rgbsort=rgbsort . "4f4f4f_gray31" . "\n"
let rgbsort=rgbsort . "525252_gray32" . "\n"
let rgbsort=rgbsort . "545454_gray33" . "\n"
let rgbsort=rgbsort . "575757_gray34" . "\n"
let rgbsort=rgbsort . "cterm_240_gui_585858" . "\n"
let rgbsort=rgbsort . "595959_gray35" . "\n"
let rgbsort=rgbsort . "5c5c5c_gray36" . "\n"
let rgbsort=rgbsort . "5e5e5e_gray37" . "\n"
let rgbsort=rgbsort . "cterm_59_gui_5f5f5f" . "\n"
let rgbsort=rgbsort . "616161_gray38" . "\n"
let rgbsort=rgbsort . "cterm_241_gui_626262" . "\n"
let rgbsort=rgbsort . "636363_gray39" . "\n"
let rgbsort=rgbsort . "666666_gray40" . "\n"
let rgbsort=rgbsort . "696969_DimGray" . "\n"
let rgbsort=rgbsort . "696969_gray41" . "\n"
let rgbsort=rgbsort . "6b6b6b_gray42" . "\n"
let rgbsort=rgbsort . "cterm_242_gui_6c6c6c" . "\n"
let rgbsort=rgbsort . "6e6e6e_gray43" . "\n"
let rgbsort=rgbsort . "707070_gray44" . "\n"
let rgbsort=rgbsort . "737373_gray45" . "\n"
let rgbsort=rgbsort . "757575_gray46" . "\n"
let rgbsort=rgbsort . "cterm_243_gui_767676" . "\n"
let rgbsort=rgbsort . "787878_gray47" . "\n"
let rgbsort=rgbsort . "7a7a7a_gray48" . "\n"
let rgbsort=rgbsort . "7d7d7d_gray49" . "\n"
let rgbsort=rgbsort . "7f7f7f_gray50" . "\n"
let rgbsort=rgbsort . "cterm_244_gui_808080" . "\n"
let rgbsort=rgbsort . "828282_gray51" . "\n"
let rgbsort=rgbsort . "858585_gray52" . "\n"
let rgbsort=rgbsort . "878787_gray53" . "\n"
let rgbsort=rgbsort . "cterm_102_gui_878787" . "\n"
let rgbsort=rgbsort . "8a8a8a_gray54" . "\n"
let rgbsort=rgbsort . "cterm_245_gui_8a8a8a" . "\n"
let rgbsort=rgbsort . "8c8c8c_gray55" . "\n"
let rgbsort=rgbsort . "8f8f8f_gray56" . "\n"
let rgbsort=rgbsort . "919191_gray57" . "\n"
let rgbsort=rgbsort . "949494_gray58" . "\n"
let rgbsort=rgbsort . "cterm_246_gui_949494" . "\n"
let rgbsort=rgbsort . "969696_gray59" . "\n"
let rgbsort=rgbsort . "999999_gray60" . "\n"
let rgbsort=rgbsort . "9c9c9c_gray61" . "\n"
let rgbsort=rgbsort . "9e9e9e_gray62" . "\n"
let rgbsort=rgbsort . "cterm_247_gui_9e9e9e" . "\n"
let rgbsort=rgbsort . "a1a1a1_gray63" . "\n"
let rgbsort=rgbsort . "a3a3a3_gray64" . "\n"
let rgbsort=rgbsort . "a6a6a6_gray65" . "\n"
let rgbsort=rgbsort . "a8a8a8_gray66" . "\n"
let rgbsort=rgbsort . "cterm_248_gui_a8a8a8" . "\n"
let rgbsort=rgbsort . "a9a9a9_DarkGray" . "\n"
let rgbsort=rgbsort . "ababab_gray67" . "\n"
let rgbsort=rgbsort . "adadad_gray68" . "\n"
let rgbsort=rgbsort . "cterm_145_gui_afafaf" . "\n"
let rgbsort=rgbsort . "b0b0b0_gray69" . "\n"
let rgbsort=rgbsort . "cterm_249_gui_b2b2b2" . "\n"
let rgbsort=rgbsort . "b3b3b3_gray70" . "\n"
let rgbsort=rgbsort . "b5b5b5_gray71" . "\n"
let rgbsort=rgbsort . "b8b8b8_gray72" . "\n"
let rgbsort=rgbsort . "bababa_gray73" . "\n"
let rgbsort=rgbsort . "cterm_250_gui_bcbcbc" . "\n"
let rgbsort=rgbsort . "bdbdbd_gray74" . "\n"
let rgbsort=rgbsort . "bebebe_gray" . "\n"
let rgbsort=rgbsort . "bfbfbf_gray75" . "\n"
let rgbsort=rgbsort . "c2c2c2_gray76" . "\n"
let rgbsort=rgbsort . "c4c4c4_gray77" . "\n"
let rgbsort=rgbsort . "cterm_251_gui_c6c6c6" . "\n"
let rgbsort=rgbsort . "c7c7c7_gray78" . "\n"
let rgbsort=rgbsort . "c9c9c9_gray79" . "\n"
let rgbsort=rgbsort . "cccccc_gray80" . "\n"
let rgbsort=rgbsort . "cfcfcf_gray81" . "\n"
let rgbsort=rgbsort . "cterm_252_gui_d0d0d0" . "\n"
let rgbsort=rgbsort . "d1d1d1_gray82" . "\n"
let rgbsort=rgbsort . "d3d3d3_LightGray" . "\n"
let rgbsort=rgbsort . "d4d4d4_gray83" . "\n"
let rgbsort=rgbsort . "d6d6d6_gray84" . "\n"
let rgbsort=rgbsort . "cterm_188_gui_d7d7d7" . "\n"
let rgbsort=rgbsort . "d9d9d9_gray85" . "\n"
let rgbsort=rgbsort . "cterm_253_gui_dadada" . "\n"
let rgbsort=rgbsort . "dbdbdb_gray86" . "\n"
let rgbsort=rgbsort . "dcdcdc_gainsboro" . "\n"
let rgbsort=rgbsort . "dedede_gray87" . "\n"
let rgbsort=rgbsort . "e0e0e0_gray88" . "\n"
let rgbsort=rgbsort . "e3e3e3_gray89" . "\n"
let rgbsort=rgbsort . "cterm_254_gui_e4e4e4" . "\n"
let rgbsort=rgbsort . "e5e5e5_gray90" . "\n"
let rgbsort=rgbsort . "e8e8e8_gray91" . "\n"
let rgbsort=rgbsort . "ebebeb_gray92" . "\n"
let rgbsort=rgbsort . "ededed_gray93" . "\n"
let rgbsort=rgbsort . "cterm_255_gui_eeeeee" . "\n"
let rgbsort=rgbsort . "f0f0f0_gray94" . "\n"
let rgbsort=rgbsort . "f2f2f2_gray95" . "\n"
let rgbsort=rgbsort . "f5f5f5_gray96" . "\n"
let rgbsort=rgbsort . "f5f5f5_WhiteSmoke" . "\n"
let rgbsort=rgbsort . "f7f7f7_gray97" . "\n"
let rgbsort=rgbsort . "fafafa_gray98" . "\n"
let rgbsort=rgbsort . "fcfcfc_gray99" . "\n"
let rgbsort=rgbsort . "cterm_15_gui_ffffff" . "\n"
let rgbsort=rgbsort . "cterm_231_gui_ffffff" . "\n"
let rgbsort=rgbsort . "ffffff_gray100" . "\n"
let rgbsort=rgbsort . "ffffff_white" . "\n"
let rgbsort=rgbsort . "8b8989_snow4" . "\n"
let rgbsort=rgbsort . "cdc9c9_snow3" . "\n"
let rgbsort=rgbsort . "eee9e9_snow2" . "\n"
let rgbsort=rgbsort . "fffafa_snow" . "\n"
let rgbsort=rgbsort . "fffafa_snow1" . "\n"
let rgbsort=rgbsort . "cterm_224_gui_ffd7d7" . "\n"
let rgbsort=rgbsort . "cterm_181_gui_d7afaf" . "\n"
let rgbsort=rgbsort . "cterm_138_gui_af8787" . "\n"
let rgbsort=rgbsort . "bc8f8f_RosyBrown" . "\n"
let rgbsort=rgbsort . "8b6969_RosyBrown4" . "\n"
let rgbsort=rgbsort . "cd9b9b_RosyBrown3" . "\n"
let rgbsort=rgbsort . "eeb4b4_RosyBrown2" . "\n"
let rgbsort=rgbsort . "ffc1c1_RosyBrown1" . "\n"
let rgbsort=rgbsort . "cterm_95_gui_875f5f" . "\n"
let rgbsort=rgbsort . "cterm_217_gui_ffafaf" . "\n"
let rgbsort=rgbsort . "cterm_174_gui_d78787" . "\n"
let rgbsort=rgbsort . "cterm_131_gui_af5f5f" . "\n"
let rgbsort=rgbsort . "f08080_LightCoral" . "\n"
let rgbsort=rgbsort . "cterm_210_gui_ff8787" . "\n"
let rgbsort=rgbsort . "cd5c5c_IndianRed" . "\n"
let rgbsort=rgbsort . "cterm_167_gui_d75f5f" . "\n"
let rgbsort=rgbsort . "8b3a3a_IndianRed4" . "\n"
let rgbsort=rgbsort . "cd5555_IndianRed3" . "\n"
let rgbsort=rgbsort . "ee6363_IndianRed2" . "\n"
let rgbsort=rgbsort . "ff6a6a_IndianRed1" . "\n"
let rgbsort=rgbsort . "cterm_203_gui_ff5f5f" . "\n"
let rgbsort=rgbsort . "a52a2a_brown" . "\n"
let rgbsort=rgbsort . "8b2323_brown4" . "\n"
let rgbsort=rgbsort . "ff4040_brown1" . "\n"
let rgbsort=rgbsort . "cd3333_brown3" . "\n"
let rgbsort=rgbsort . "ee3b3b_brown2" . "\n"
let rgbsort=rgbsort . "b22222_firebrick" . "\n"
let rgbsort=rgbsort . "8b1a1a_firebrick4" . "\n"
let rgbsort=rgbsort . "ff3030_firebrick1" . "\n"
let rgbsort=rgbsort . "cd2626_firebrick3" . "\n"
let rgbsort=rgbsort . "ee2c2c_firebrick2" . "\n"
let rgbsort=rgbsort . "cterm_52_gui_5f0000" . "\n"
let rgbsort=rgbsort . "cterm_88_gui_870000" . "\n"
let rgbsort=rgbsort . "8b0000_DarkRed" . "\n"
let rgbsort=rgbsort . "8b0000_red4" . "\n"
let rgbsort=rgbsort . "cterm_124_gui_af0000" . "\n"
let rgbsort=rgbsort . "cd0000_red3" . "\n"
let rgbsort=rgbsort . "cterm_1_gui_ce0000" . "\n"
let rgbsort=rgbsort . "cterm_160_gui_d70000" . "\n"
let rgbsort=rgbsort . "ee0000_red2" . "\n"
let rgbsort=rgbsort . "cterm_196_gui_ff0000" . "\n"
let rgbsort=rgbsort . "cterm_9_gui_ff0000" . "\n"
let rgbsort=rgbsort . "ff0000_red" . "\n"
let rgbsort=rgbsort . "ff0000_red1" . "\n"
let rgbsort=rgbsort . "cdb7b5_MistyRose3" . "\n"
let rgbsort=rgbsort . "eed5d2_MistyRose2" . "\n"
let rgbsort=rgbsort . "ffe4e1_MistyRose" . "\n"
let rgbsort=rgbsort . "ffe4e1_MistyRose1" . "\n"
let rgbsort=rgbsort . "fa8072_salmon" . "\n"
let rgbsort=rgbsort . "8b7d7b_MistyRose4" . "\n"
let rgbsort=rgbsort . "cd4f39_tomato3" . "\n"
let rgbsort=rgbsort . "ee5c42_tomato2" . "\n"
let rgbsort=rgbsort . "ff6347_tomato" . "\n"
let rgbsort=rgbsort . "ff6347_tomato1" . "\n"
let rgbsort=rgbsort . "8b3e2f_coral4" . "\n"
let rgbsort=rgbsort . "cd5b45_coral3" . "\n"
let rgbsort=rgbsort . "ee6a50_coral2" . "\n"
let rgbsort=rgbsort . "ff7256_coral1" . "\n"
let rgbsort=rgbsort . "8b3626_tomato4" . "\n"
let rgbsort=rgbsort . "8b4c39_salmon4" . "\n"
let rgbsort=rgbsort . "ee8262_salmon2" . "\n"
let rgbsort=rgbsort . "ff8c69_salmon1" . "\n"
let rgbsort=rgbsort . "cd7054_salmon3" . "\n"
let rgbsort=rgbsort . "e9967a_DarkSalmon" . "\n"
let rgbsort=rgbsort . "cterm_209_gui_ff875f" . "\n"
let rgbsort=rgbsort . "ff7f50_coral" . "\n"
let rgbsort=rgbsort . "8b2500_OrangeRed4" . "\n"
let rgbsort=rgbsort . "cd3700_OrangeRed3" . "\n"
let rgbsort=rgbsort . "ee4000_OrangeRed2" . "\n"
let rgbsort=rgbsort . "ff4500_OrangeRed" . "\n"
let rgbsort=rgbsort . "ff4500_OrangeRed1" . "\n"
let rgbsort=rgbsort . "cd8162_LightSalmon3" . "\n"
let rgbsort=rgbsort . "ee9572_LightSalmon2" . "\n"
let rgbsort=rgbsort . "ffa07a_LightSalmon" . "\n"
let rgbsort=rgbsort . "ffa07a_LightSalmon1" . "\n"
let rgbsort=rgbsort . "8b5742_LightSalmon4" . "\n"
let rgbsort=rgbsort . "a0522d_sienna" . "\n"
let rgbsort=rgbsort . "cd6839_sienna3" . "\n"
let rgbsort=rgbsort . "ee7942_sienna2" . "\n"
let rgbsort=rgbsort . "ff8247_sienna1" . "\n"
let rgbsort=rgbsort . "cterm_216_gui_ffaf87" . "\n"
let rgbsort=rgbsort . "cterm_173_gui_d7875f" . "\n"
let rgbsort=rgbsort . "8b4726_sienna4" . "\n"
let rgbsort=rgbsort . "cterm_202_gui_ff5f00" . "\n"
let rgbsort=rgbsort . "fff5ee_seashell" . "\n"
let rgbsort=rgbsort . "fff5ee_seashell1" . "\n"
let rgbsort=rgbsort . "cd661d_chocolate3" . "\n"
let rgbsort=rgbsort . "d2691e_chocolate" . "\n"
let rgbsort=rgbsort . "ff7f24_chocolate1" . "\n"
let rgbsort=rgbsort . "8b4513_chocolate4" . "\n"
let rgbsort=rgbsort . "8b4513_SaddleBrown" . "\n"
let rgbsort=rgbsort . "ee7621_chocolate2" . "\n"
let rgbsort=rgbsort . "cdc5bf_seashell3" . "\n"
let rgbsort=rgbsort . "eee5de_seashell2" . "\n"
let rgbsort=rgbsort . "8b8682_seashell4" . "\n"
let rgbsort=rgbsort . "cterm_166_gui_d75f00" . "\n"
let rgbsort=rgbsort . "8b7765_PeachPuff4" . "\n"
let rgbsort=rgbsort . "cdaf95_PeachPuff3" . "\n"
let rgbsort=rgbsort . "eecbad_PeachPuff2" . "\n"
let rgbsort=rgbsort . "ffdab9_PeachPuff" . "\n"
let rgbsort=rgbsort . "ffdab9_PeachPuff1" . "\n"
let rgbsort=rgbsort . "f4a460_SandyBrown" . "\n"
let rgbsort=rgbsort . "8b5a2b_tan4" . "\n"
let rgbsort=rgbsort . "ffa54f_tan1" . "\n"
let rgbsort=rgbsort . "ee9a49_tan2" . "\n"
let rgbsort=rgbsort . "faf0e6_linen" . "\n"
let rgbsort=rgbsort . "cterm_223_gui_ffd7af" . "\n"
let rgbsort=rgbsort . "cterm_180_gui_d7af87" . "\n"
let rgbsort=rgbsort . "cterm_137_gui_af875f" . "\n"
let rgbsort=rgbsort . "cterm_215_gui_ffaf5f" . "\n"
let rgbsort=rgbsort . "cd853f_peru" . "\n"
let rgbsort=rgbsort . "cd853f_tan3" . "\n"
let rgbsort=rgbsort . "8b4500_DarkOrange4" . "\n"
let rgbsort=rgbsort . "cd6600_DarkOrange3" . "\n"
let rgbsort=rgbsort . "ee7600_DarkOrange2" . "\n"
let rgbsort=rgbsort . "ff7f00_DarkOrange1" . "\n"
let rgbsort=rgbsort . "cdb79e_bisque3" . "\n"
let rgbsort=rgbsort . "cterm_208_gui_ff8700" . "\n"
let rgbsort=rgbsort . "cdc0b0_AntiqueWhite3" . "\n"
let rgbsort=rgbsort . "ffefdb_AntiqueWhite1" . "\n"
let rgbsort=rgbsort . "eed5b7_bisque2" . "\n"
let rgbsort=rgbsort . "ffe4c4_bisque" . "\n"
let rgbsort=rgbsort . "ffe4c4_bisque1" . "\n"
let rgbsort=rgbsort . "8b7355_burlywood4" . "\n"
let rgbsort=rgbsort . "cterm_130_gui_af5f00" . "\n"
let rgbsort=rgbsort . "ff8c00_DarkOrange" . "\n"
let rgbsort=rgbsort . "eedfcc_AntiqueWhite2" . "\n"
let rgbsort=rgbsort . "faebd7_AntiqueWhite" . "\n"
let rgbsort=rgbsort . "8b7d6b_bisque4" . "\n"
let rgbsort=rgbsort . "d2b48c_tan" . "\n"
let rgbsort=rgbsort . "cdaa7d_burlywood3" . "\n"
let rgbsort=rgbsort . "deb887_burlywood" . "\n"
let rgbsort=rgbsort . "eec591_burlywood2" . "\n"
let rgbsort=rgbsort . "ffd39b_burlywood1" . "\n"
let rgbsort=rgbsort . "8b8378_AntiqueWhite4" . "\n"
let rgbsort=rgbsort . "ffebcd_BlanchedAlmond" . "\n"
let rgbsort=rgbsort . "cdb38b_NavajoWhite3" . "\n"
let rgbsort=rgbsort . "ffdead_NavajoWhite" . "\n"
let rgbsort=rgbsort . "ffdead_NavajoWhite1" . "\n"
let rgbsort=rgbsort . "8b795e_NavajoWhite4" . "\n"
let rgbsort=rgbsort . "eecfa1_NavajoWhite2" . "\n"
let rgbsort=rgbsort . "ffefd5_PapayaWhip" . "\n"
let rgbsort=rgbsort . "ffe4b5_moccasin" . "\n"
let rgbsort=rgbsort . "cterm_172_gui_d78700" . "\n"
let rgbsort=rgbsort . "fdf5e6_OldLace" . "\n"
let rgbsort=rgbsort . "8b7e66_wheat4" . "\n"
let rgbsort=rgbsort . "cdba96_wheat3" . "\n"
let rgbsort=rgbsort . "eed8ae_wheat2" . "\n"
let rgbsort=rgbsort . "f5deb3_wheat" . "\n"
let rgbsort=rgbsort . "ffe7ba_wheat1" . "\n"
let rgbsort=rgbsort . "8b5a00_orange4" . "\n"
let rgbsort=rgbsort . "cd8500_orange3" . "\n"
let rgbsort=rgbsort . "ee9a00_orange2" . "\n"
let rgbsort=rgbsort . "ffa500_orange" . "\n"
let rgbsort=rgbsort . "ffa500_orange1" . "\n"
let rgbsort=rgbsort . "fffaf0_FloralWhite" . "\n"
let rgbsort=rgbsort . "cterm_222_gui_ffd787" . "\n"
let rgbsort=rgbsort . "cterm_179_gui_d7af5f" . "\n"
let rgbsort=rgbsort . "cterm_214_gui_ffaf00" . "\n"
let rgbsort=rgbsort . "cterm_94_gui_875f00" . "\n"
let rgbsort=rgbsort . "8b6914_goldenrod4" . "\n"
let rgbsort=rgbsort . "daa520_goldenrod" . "\n"
let rgbsort=rgbsort . "ffc125_goldenrod1" . "\n"
let rgbsort=rgbsort . "cd9b1d_goldenrod3" . "\n"
let rgbsort=rgbsort . "eeb422_goldenrod2" . "\n"
let rgbsort=rgbsort . "8b6508_DarkGoldenrod4" . "\n"
let rgbsort=rgbsort . "b8860b_DarkGoldenrod" . "\n"
let rgbsort=rgbsort . "cd950c_DarkGoldenrod3" . "\n"
let rgbsort=rgbsort . "eead0e_DarkGoldenrod2" . "\n"
let rgbsort=rgbsort . "ffb90f_DarkGoldenrod1" . "\n"
let rgbsort=rgbsort . "cterm_221_gui_ffd75f" . "\n"
let rgbsort=rgbsort . "cterm_136_gui_af8700" . "\n"
let rgbsort=rgbsort . "fff8dc_cornsilk" . "\n"
let rgbsort=rgbsort . "fff8dc_cornsilk1" . "\n"
let rgbsort=rgbsort . "cdc8b1_cornsilk3" . "\n"
let rgbsort=rgbsort . "eee8cd_cornsilk2" . "\n"
let rgbsort=rgbsort . "cterm_178_gui_d7af00" . "\n"
let rgbsort=rgbsort . "8b814c_LightGoldenrod4" . "\n"
let rgbsort=rgbsort . "cdbe70_LightGoldenrod3" . "\n"
let rgbsort=rgbsort . "eedc82_LightGoldenrod2" . "\n"
let rgbsort=rgbsort . "ffec8b_LightGoldenrod1" . "\n"
let rgbsort=rgbsort . "8b8878_cornsilk4" . "\n"
let rgbsort=rgbsort . "eedd82_LightGoldenrod" . "\n"
let rgbsort=rgbsort . "8b7500_gold4" . "\n"
let rgbsort=rgbsort . "cdad00_gold3" . "\n"
let rgbsort=rgbsort . "eec900_gold2" . "\n"
let rgbsort=rgbsort . "cterm_220_gui_ffd700" . "\n"
let rgbsort=rgbsort . "ffd700_gold" . "\n"
let rgbsort=rgbsort . "ffd700_gold1" . "\n"
let rgbsort=rgbsort . "cdc9a5_LemonChiffon3" . "\n"
let rgbsort=rgbsort . "eee9bf_LemonChiffon2" . "\n"
let rgbsort=rgbsort . "fffacd_LemonChiffon" . "\n"
let rgbsort=rgbsort . "fffacd_LemonChiffon1" . "\n"
let rgbsort=rgbsort . "f0e68c_khaki" . "\n"
let rgbsort=rgbsort . "eee8aa_PaleGoldenrod" . "\n"
let rgbsort=rgbsort . "8b864e_khaki4" . "\n"
let rgbsort=rgbsort . "cdc673_khaki3" . "\n"
let rgbsort=rgbsort . "fff68f_khaki1" . "\n"
let rgbsort=rgbsort . "eee685_khaki2" . "\n"
let rgbsort=rgbsort . "8b8970_LemonChiffon4" . "\n"
let rgbsort=rgbsort . "bdb76b_DarkKhaki" . "\n"
let rgbsort=rgbsort . "cterm_3_gui_cecb00" . "\n"
let rgbsort=rgbsort . "8b8b83_ivory4" . "\n"
let rgbsort=rgbsort . "cdcdc1_ivory3" . "\n"
let rgbsort=rgbsort . "eeeee0_ivory2" . "\n"
let rgbsort=rgbsort . "fffff0_ivory" . "\n"
let rgbsort=rgbsort . "fffff0_ivory1" . "\n"
let rgbsort=rgbsort . "f5f5dc_beige" . "\n"
let rgbsort=rgbsort . "8b8b7a_LightYellow4" . "\n"
let rgbsort=rgbsort . "cdcdb4_LightYellow3" . "\n"
let rgbsort=rgbsort . "eeeed1_LightYellow2" . "\n"
let rgbsort=rgbsort . "ffffe0_LightYellow" . "\n"
let rgbsort=rgbsort . "ffffe0_LightYellow1" . "\n"
let rgbsort=rgbsort . "cterm_230_gui_ffffd7" . "\n"
let rgbsort=rgbsort . "fafad2_LightGoldenrodYellow" . "\n"
let rgbsort=rgbsort . "cterm_187_gui_d7d7af" . "\n"
let rgbsort=rgbsort . "cterm_144_gui_afaf87" . "\n"
let rgbsort=rgbsort . "cterm_101_gui_87875f" . "\n"
let rgbsort=rgbsort . "cterm_229_gui_ffffaf" . "\n"
let rgbsort=rgbsort . "cterm_186_gui_d7d787" . "\n"
let rgbsort=rgbsort . "cterm_143_gui_afaf5f" . "\n"
let rgbsort=rgbsort . "cterm_228_gui_ffff87" . "\n"
let rgbsort=rgbsort . "cterm_185_gui_d7d75f" . "\n"
let rgbsort=rgbsort . "cterm_227_gui_ffff5f" . "\n"
let rgbsort=rgbsort . "cterm_58_gui_5f5f00" . "\n"
let rgbsort=rgbsort . "cterm_100_gui_878700" . "\n"
let rgbsort=rgbsort . "8b8b00_yellow4" . "\n"
let rgbsort=rgbsort . "cterm_142_gui_afaf00" . "\n"
let rgbsort=rgbsort . "cdcd00_yellow3" . "\n"
let rgbsort=rgbsort . "cterm_184_gui_d7d700" . "\n"
let rgbsort=rgbsort . "eeee00_yellow2" . "\n"
let rgbsort=rgbsort . "cterm_11_gui_ffff00" . "\n"
let rgbsort=rgbsort . "cterm_226_gui_ffff00" . "\n"
let rgbsort=rgbsort . "ffff00_yellow" . "\n"
let rgbsort=rgbsort . "ffff00_yellow1" . "\n"
let rgbsort=rgbsort . "cterm_190_gui_d7ff00" . "\n"
let rgbsort=rgbsort . "cterm_148_gui_afd700" . "\n"
let rgbsort=rgbsort . "cterm_106_gui_87af00" . "\n"
let rgbsort=rgbsort . "cterm_191_gui_d7ff5f" . "\n"
let rgbsort=rgbsort . "cterm_64_gui_5f8700" . "\n"
let rgbsort=rgbsort . "cterm_154_gui_afff00" . "\n"
let rgbsort=rgbsort . "cterm_192_gui_d7ff87" . "\n"
let rgbsort=rgbsort . "cterm_149_gui_afd75f" . "\n"
let rgbsort=rgbsort . "6b8e23_OliveDrab" . "\n"
let rgbsort=rgbsort . "698b22_OliveDrab4" . "\n"
let rgbsort=rgbsort . "9acd32_OliveDrab3" . "\n"
let rgbsort=rgbsort . "9acd32_YellowGreen" . "\n"
let rgbsort=rgbsort . "b3ee3a_OliveDrab2" . "\n"
let rgbsort=rgbsort . "c0ff3e_OliveDrab1" . "\n"
let rgbsort=rgbsort . "556b2f_DarkOliveGreen" . "\n"
let rgbsort=rgbsort . "6e8b3d_DarkOliveGreen4" . "\n"
let rgbsort=rgbsort . "caff70_DarkOliveGreen1" . "\n"
let rgbsort=rgbsort . "bcee68_DarkOliveGreen2" . "\n"
let rgbsort=rgbsort . "cterm_112_gui_87d700" . "\n"
let rgbsort=rgbsort . "a2cd5a_DarkOliveGreen3" . "\n"
let rgbsort=rgbsort . "adff2f_GreenYellow" . "\n"
let rgbsort=rgbsort . "cterm_70_gui_5faf00" . "\n"
let rgbsort=rgbsort . "cterm_118_gui_87ff00" . "\n"
let rgbsort=rgbsort . "cterm_193_gui_d7ffaf" . "\n"
let rgbsort=rgbsort . "cterm_150_gui_afd787" . "\n"
let rgbsort=rgbsort . "cterm_107_gui_87af5f" . "\n"
let rgbsort=rgbsort . "cterm_155_gui_afff5f" . "\n"
let rgbsort=rgbsort . "458b00_chartreuse4" . "\n"
let rgbsort=rgbsort . "66cd00_chartreuse3" . "\n"
let rgbsort=rgbsort . "76ee00_chartreuse2" . "\n"
let rgbsort=rgbsort . "7fff00_chartreuse" . "\n"
let rgbsort=rgbsort . "7fff00_chartreuse1" . "\n"
let rgbsort=rgbsort . "7cfc00_LawnGreen" . "\n"
let rgbsort=rgbsort . "cterm_76_gui_5fd700" . "\n"
let rgbsort=rgbsort . "cterm_82_gui_5fff00" . "\n"
let rgbsort=rgbsort . "cterm_156_gui_afff87" . "\n"
let rgbsort=rgbsort . "cterm_113_gui_87d75f" . "\n"
let rgbsort=rgbsort . "cterm_119_gui_87ff5f" . "\n"
let rgbsort=rgbsort . "cterm_8_gui_7b7d7b" . "\n"
let rgbsort=rgbsort . "838b83_honeydew4" . "\n"
let rgbsort=rgbsort . "c1cdc1_honeydew3" . "\n"
let rgbsort=rgbsort . "e0eee0_honeydew2" . "\n"
let rgbsort=rgbsort . "f0fff0_honeydew" . "\n"
let rgbsort=rgbsort . "f0fff0_honeydew1" . "\n"
let rgbsort=rgbsort . "cterm_194_gui_d7ffd7" . "\n"
let rgbsort=rgbsort . "cterm_151_gui_afd7af" . "\n"
let rgbsort=rgbsort . "cterm_108_gui_87af87" . "\n"
let rgbsort=rgbsort . "8fbc8f_DarkSeaGreen" . "\n"
let rgbsort=rgbsort . "698b69_DarkSeaGreen4" . "\n"
let rgbsort=rgbsort . "9bcd9b_DarkSeaGreen3" . "\n"
let rgbsort=rgbsort . "b4eeb4_DarkSeaGreen2" . "\n"
let rgbsort=rgbsort . "c1ffc1_DarkSeaGreen1" . "\n"
let rgbsort=rgbsort . "cterm_65_gui_5f875f" . "\n"
let rgbsort=rgbsort . "cterm_157_gui_afffaf" . "\n"
let rgbsort=rgbsort . "cterm_114_gui_87d787" . "\n"
let rgbsort=rgbsort . "548b54_PaleGreen4" . "\n"
let rgbsort=rgbsort . "7ccd7c_PaleGreen3" . "\n"
let rgbsort=rgbsort . "90ee90_LightGreen" . "\n"
let rgbsort=rgbsort . "90ee90_PaleGreen2" . "\n"
let rgbsort=rgbsort . "98fb98_PaleGreen" . "\n"
let rgbsort=rgbsort . "9aff9a_PaleGreen1" . "\n"
let rgbsort=rgbsort . "cterm_71_gui_5faf5f" . "\n"
let rgbsort=rgbsort . "cterm_120_gui_87ff87" . "\n"
let rgbsort=rgbsort . "cterm_77_gui_5fd75f" . "\n"
let rgbsort=rgbsort . "cterm_83_gui_5fff5f" . "\n"
let rgbsort=rgbsort . "228b22_ForestGreen" . "\n"
let rgbsort=rgbsort . "32cd32_LimeGreen" . "\n"
let rgbsort=rgbsort . "cterm_22_gui_005f00" . "\n"
let rgbsort=rgbsort . "006400_DarkGreen" . "\n"
let rgbsort=rgbsort . "cterm_28_gui_008700" . "\n"
let rgbsort=rgbsort . "008b00_green4" . "\n"
let rgbsort=rgbsort . "cterm_34_gui_00af00" . "\n"
let rgbsort=rgbsort . "cterm_2_gui_00cb00" . "\n"
let rgbsort=rgbsort . "00cd00_green3" . "\n"
let rgbsort=rgbsort . "cterm_40_gui_00d700" . "\n"
let rgbsort=rgbsort . "00ee00_green2" . "\n"
let rgbsort=rgbsort . "00ff00_green" . "\n"
let rgbsort=rgbsort . "00ff00_green1" . "\n"
let rgbsort=rgbsort . "cterm_10_gui_00ff00" . "\n"
let rgbsort=rgbsort . "cterm_46_gui_00ff00" . "\n"
let rgbsort=rgbsort . "cterm_84_gui_5fff87" . "\n"
let rgbsort=rgbsort . "cterm_121_gui_87ffaf" . "\n"
let rgbsort=rgbsort . "cterm_78_gui_5fd787" . "\n"
let rgbsort=rgbsort . "cterm_47_gui_00ff5f" . "\n"
let rgbsort=rgbsort . "2e8b57_SeaGreen" . "\n"
let rgbsort=rgbsort . "2e8b57_SeaGreen4" . "\n"
let rgbsort=rgbsort . "4eee94_SeaGreen2" . "\n"
let rgbsort=rgbsort . "54ff9f_SeaGreen1" . "\n"
let rgbsort=rgbsort . "3cb371_MediumSeaGreen" . "\n"
let rgbsort=rgbsort . "43cd80_SeaGreen3" . "\n"
let rgbsort=rgbsort . "cterm_41_gui_00d75f" . "\n"
let rgbsort=rgbsort . "f5fffa_MintCream" . "\n"
let rgbsort=rgbsort . "cterm_158_gui_afffd7" . "\n"
let rgbsort=rgbsort . "cterm_115_gui_87d7af" . "\n"
let rgbsort=rgbsort . "cterm_72_gui_5faf87" . "\n"
let rgbsort=rgbsort . "cterm_85_gui_5fffaf" . "\n"
let rgbsort=rgbsort . "008b45_SpringGreen4" . "\n"
let rgbsort=rgbsort . "00cd66_SpringGreen3" . "\n"
let rgbsort=rgbsort . "00ee76_SpringGreen2" . "\n"
let rgbsort=rgbsort . "00ff7f_SpringGreen" . "\n"
let rgbsort=rgbsort . "00ff7f_SpringGreen1" . "\n"
let rgbsort=rgbsort . "cterm_48_gui_00ff87" . "\n"
let rgbsort=rgbsort . "cterm_35_gui_00af5f" . "\n"
let rgbsort=rgbsort . "00fa9a_MediumSpringGreen" . "\n"
let rgbsort=rgbsort . "cterm_42_gui_00d787" . "\n"
let rgbsort=rgbsort . "cterm_122_gui_87ffd7" . "\n"
let rgbsort=rgbsort . "458b74_aquamarine4" . "\n"
let rgbsort=rgbsort . "66cdaa_aquamarine3" . "\n"
let rgbsort=rgbsort . "66cdaa_MediumAquamarine" . "\n"
let rgbsort=rgbsort . "7fffd4_aquamarine" . "\n"
let rgbsort=rgbsort . "7fffd4_aquamarine1" . "\n"
let rgbsort=rgbsort . "76eec6_aquamarine2" . "\n"
let rgbsort=rgbsort . "cterm_79_gui_5fd7af" . "\n"
let rgbsort=rgbsort . "cterm_49_gui_00ffaf" . "\n"
let rgbsort=rgbsort . "cterm_29_gui_00875f" . "\n"
let rgbsort=rgbsort . "cterm_86_gui_5fffd7" . "\n"
let rgbsort=rgbsort . "cterm_36_gui_00af87" . "\n"
let rgbsort=rgbsort . "cterm_43_gui_00d7af" . "\n"
let rgbsort=rgbsort . "cterm_50_gui_00ffd7" . "\n"
let rgbsort=rgbsort . "40e0d0_turquoise" . "\n"
let rgbsort=rgbsort . "20b2aa_LightSeaGreen" . "\n"
let rgbsort=rgbsort . "48d1cc_MediumTurquoise" . "\n"
let rgbsort=rgbsort . "838b8b_azure4" . "\n"
let rgbsort=rgbsort . "c1cdcd_azure3" . "\n"
let rgbsort=rgbsort . "e0eeee_azure2" . "\n"
let rgbsort=rgbsort . "f0ffff_azure" . "\n"
let rgbsort=rgbsort . "f0ffff_azure1" . "\n"
let rgbsort=rgbsort . "7a8b8b_LightCyan4" . "\n"
let rgbsort=rgbsort . "b4cdcd_LightCyan3" . "\n"
let rgbsort=rgbsort . "d1eeee_LightCyan2" . "\n"
let rgbsort=rgbsort . "e0ffff_LightCyan" . "\n"
let rgbsort=rgbsort . "e0ffff_LightCyan1" . "\n"
let rgbsort=rgbsort . "cterm_195_gui_d7ffff" . "\n"
let rgbsort=rgbsort . "cterm_152_gui_afd7d7" . "\n"
let rgbsort=rgbsort . "cterm_109_gui_87afaf" . "\n"
let rgbsort=rgbsort . "668b8b_PaleTurquoise4" . "\n"
let rgbsort=rgbsort . "96cdcd_PaleTurquoise3" . "\n"
let rgbsort=rgbsort . "afeeee_PaleTurquoise" . "\n"
let rgbsort=rgbsort . "bbffff_PaleTurquoise1" . "\n"
let rgbsort=rgbsort . "aeeeee_PaleTurquoise2" . "\n"
let rgbsort=rgbsort . "cterm_66_gui_5f8787" . "\n"
let rgbsort=rgbsort . "cterm_159_gui_afffff" . "\n"
let rgbsort=rgbsort . "cterm_116_gui_87d7d7" . "\n"
let rgbsort=rgbsort . "2f4f4f_DarkSlateGray" . "\n"
let rgbsort=rgbsort . "79cdcd_DarkSlateGray3" . "\n"
let rgbsort=rgbsort . "8deeee_DarkSlateGray2" . "\n"
let rgbsort=rgbsort . "97ffff_DarkSlateGray1" . "\n"
let rgbsort=rgbsort . "528b8b_DarkSlateGray4" . "\n"
let rgbsort=rgbsort . "cterm_73_gui_5fafaf" . "\n"
let rgbsort=rgbsort . "cterm_123_gui_87ffff" . "\n"
let rgbsort=rgbsort . "cterm_80_gui_5fd7d7" . "\n"
let rgbsort=rgbsort . "cterm_87_gui_5fffff" . "\n"
let rgbsort=rgbsort . "cterm_23_gui_005f5f" . "\n"
let rgbsort=rgbsort . "cterm_30_gui_008787" . "\n"
let rgbsort=rgbsort . "008b8b_cyan4" . "\n"
let rgbsort=rgbsort . "008b8b_DarkCyan" . "\n"
let rgbsort=rgbsort . "cterm_37_gui_00afaf" . "\n"
let rgbsort=rgbsort . "00cdcd_cyan3" . "\n"
let rgbsort=rgbsort . "cterm_44_gui_00d7d7" . "\n"
let rgbsort=rgbsort . "00eeee_cyan2" . "\n"
let rgbsort=rgbsort . "00ffff_cyan" . "\n"
let rgbsort=rgbsort . "00ffff_cyan1" . "\n"
let rgbsort=rgbsort . "cterm_14_gui_00ffff" . "\n"
let rgbsort=rgbsort . "cterm_51_gui_00ffff" . "\n"
let rgbsort=rgbsort . "cterm_6_gui_00cbce" . "\n"
let rgbsort=rgbsort . "00ced1_DarkTurquoise" . "\n"
let rgbsort=rgbsort . "5f9ea0_CadetBlue" . "\n"
let rgbsort=rgbsort . "00868b_turquoise4" . "\n"
let rgbsort=rgbsort . "00c5cd_turquoise3" . "\n"
let rgbsort=rgbsort . "00e5ee_turquoise2" . "\n"
let rgbsort=rgbsort . "00f5ff_turquoise1" . "\n"
let rgbsort=rgbsort . "53868b_CadetBlue4" . "\n"
let rgbsort=rgbsort . "7ac5cd_CadetBlue3" . "\n"
let rgbsort=rgbsort . "8ee5ee_CadetBlue2" . "\n"
let rgbsort=rgbsort . "98f5ff_CadetBlue1" . "\n"
let rgbsort=rgbsort . "b0e0e6_PowderBlue" . "\n"
let rgbsort=rgbsort . "cterm_45_gui_00d7ff" . "\n"
let rgbsort=rgbsort . "cterm_38_gui_00afd7" . "\n"
let rgbsort=rgbsort . "68838b_LightBlue4" . "\n"
let rgbsort=rgbsort . "cterm_31_gui_0087af" . "\n"
let rgbsort=rgbsort . "9ac0cd_LightBlue3" . "\n"
let rgbsort=rgbsort . "add8e6_LightBlue" . "\n"
let rgbsort=rgbsort . "b2dfee_LightBlue2" . "\n"
let rgbsort=rgbsort . "bfefff_LightBlue1" . "\n"
let rgbsort=rgbsort . "cterm_81_gui_5fd7ff" . "\n"
let rgbsort=rgbsort . "00688b_DeepSkyBlue4" . "\n"
let rgbsort=rgbsort . "009acd_DeepSkyBlue3" . "\n"
let rgbsort=rgbsort . "00b2ee_DeepSkyBlue2" . "\n"
let rgbsort=rgbsort . "00bfff_DeepSkyBlue" . "\n"
let rgbsort=rgbsort . "00bfff_DeepSkyBlue1" . "\n"
let rgbsort=rgbsort . "87ceeb_SkyBlue" . "\n"
let rgbsort=rgbsort . "cterm_24_gui_005f87" . "\n"
let rgbsort=rgbsort . "cterm_39_gui_00afff" . "\n"
let rgbsort=rgbsort . "cterm_117_gui_87d7ff" . "\n"
let rgbsort=rgbsort . "cterm_74_gui_5fafd7" . "\n"
let rgbsort=rgbsort . "607b8b_LightSkyBlue4" . "\n"
let rgbsort=rgbsort . "a4d3ee_LightSkyBlue2" . "\n"
let rgbsort=rgbsort . "b0e2ff_LightSkyBlue1" . "\n"
let rgbsort=rgbsort . "8db6cd_LightSkyBlue3" . "\n"
let rgbsort=rgbsort . "cterm_32_gui_0087d7" . "\n"
let rgbsort=rgbsort . "87cefa_LightSkyBlue" . "\n"
let rgbsort=rgbsort . "6ca6cd_SkyBlue3" . "\n"
let rgbsort=rgbsort . "4a708b_SkyBlue4" . "\n"
let rgbsort=rgbsort . "7ec0ee_SkyBlue2" . "\n"
let rgbsort=rgbsort . "87ceff_SkyBlue1" . "\n"
let rgbsort=rgbsort . "4682b4_SteelBlue" . "\n"
let rgbsort=rgbsort . "5cacee_SteelBlue2" . "\n"
let rgbsort=rgbsort . "63b8ff_SteelBlue1" . "\n"
let rgbsort=rgbsort . "4f94cd_SteelBlue3" . "\n"
let rgbsort=rgbsort . "f0f8ff_AliceBlue" . "\n"
let rgbsort=rgbsort . "36648b_SteelBlue4" . "\n"
let rgbsort=rgbsort . "cterm_25_gui_005faf" . "\n"
let rgbsort=rgbsort . "cterm_33_gui_0087ff" . "\n"
let rgbsort=rgbsort . "708090_SlateGray" . "\n"
let rgbsort=rgbsort . "778899_LightSlateGray" . "\n"
let rgbsort=rgbsort . "9fb6cd_SlateGray3" . "\n"
let rgbsort=rgbsort . "cterm_153_gui_afd7ff" . "\n"
let rgbsort=rgbsort . "cterm_110_gui_87afd7" . "\n"
let rgbsort=rgbsort . "cterm_67_gui_5f87af" . "\n"
let rgbsort=rgbsort . "cterm_75_gui_5fafff" . "\n"
let rgbsort=rgbsort . "1874cd_DodgerBlue3" . "\n"
let rgbsort=rgbsort . "1c86ee_DodgerBlue2" . "\n"
let rgbsort=rgbsort . "1e90ff_DodgerBlue" . "\n"
let rgbsort=rgbsort . "1e90ff_DodgerBlue1" . "\n"
let rgbsort=rgbsort . "104e8b_DodgerBlue4" . "\n"
let rgbsort=rgbsort . "6c7b8b_SlateGray4" . "\n"
let rgbsort=rgbsort . "b9d3ee_SlateGray2" . "\n"
let rgbsort=rgbsort . "c6e2ff_SlateGray1" . "\n"
let rgbsort=rgbsort . "6e7b8b_LightSteelBlue4" . "\n"
let rgbsort=rgbsort . "a2b5cd_LightSteelBlue3" . "\n"
let rgbsort=rgbsort . "b0c4de_LightSteelBlue" . "\n"
let rgbsort=rgbsort . "cae1ff_LightSteelBlue1" . "\n"
let rgbsort=rgbsort . "bcd2ee_LightSteelBlue2" . "\n"
let rgbsort=rgbsort . "cterm_26_gui_005fd7" . "\n"
let rgbsort=rgbsort . "cterm_27_gui_005fff" . "\n"
let rgbsort=rgbsort . "6495ed_CornflowerBlue" . "\n"
let rgbsort=rgbsort . "cterm_111_gui_87afff" . "\n"
let rgbsort=rgbsort . "cterm_68_gui_5f87d7" . "\n"
let rgbsort=rgbsort . "cterm_69_gui_5f87ff" . "\n"
let rgbsort=rgbsort . "4169e1_RoyalBlue" . "\n"
let rgbsort=rgbsort . "27408b_RoyalBlue4" . "\n"
let rgbsort=rgbsort . "3a5fcd_RoyalBlue3" . "\n"
let rgbsort=rgbsort . "436eee_RoyalBlue2" . "\n"
let rgbsort=rgbsort . "4876ff_RoyalBlue1" . "\n"
let rgbsort=rgbsort . "cterm_12_gui_5a5dff" . "\n"
let rgbsort=rgbsort . "f8f8ff_GhostWhite" . "\n"
let rgbsort=rgbsort . "e6e6fa_lavender" . "\n"
let rgbsort=rgbsort . "cterm_189_gui_d7d7ff" . "\n"
let rgbsort=rgbsort . "cterm_146_gui_afafd7" . "\n"
let rgbsort=rgbsort . "cterm_103_gui_8787af" . "\n"
let rgbsort=rgbsort . "cterm_60_gui_5f5f87" . "\n"
let rgbsort=rgbsort . "cterm_147_gui_afafff" . "\n"
let rgbsort=rgbsort . "cterm_104_gui_8787d7" . "\n"
let rgbsort=rgbsort . "cterm_61_gui_5f5faf" . "\n"
let rgbsort=rgbsort . "cterm_105_gui_8787ff" . "\n"
let rgbsort=rgbsort . "cterm_62_gui_5f5fd7" . "\n"
let rgbsort=rgbsort . "cterm_63_gui_5f5fff" . "\n"
let rgbsort=rgbsort . "191970_MidnightBlue" . "\n"
let rgbsort=rgbsort . "cterm_17_gui_00005f" . "\n"
let rgbsort=rgbsort . "000080_navy" . "\n"
let rgbsort=rgbsort . "cterm_18_gui_000087" . "\n"
let rgbsort=rgbsort . "00008b_blue4" . "\n"
let rgbsort=rgbsort . "00008b_DarkBlue" . "\n"
let rgbsort=rgbsort . "cterm_19_gui_0000af" . "\n"
let rgbsort=rgbsort . "0000cd_blue3" . "\n"
let rgbsort=rgbsort . "0000cd_MediumBlue" . "\n"
let rgbsort=rgbsort . "cterm_20_gui_0000d7" . "\n"
let rgbsort=rgbsort . "0000ee_blue2" . "\n"
let rgbsort=rgbsort . "cterm_4_gui_0000ef" . "\n"
let rgbsort=rgbsort . "0000ff_blue" . "\n"
let rgbsort=rgbsort . "0000ff_blue1" . "\n"
let rgbsort=rgbsort . "cterm_21_gui_0000ff" . "\n"
let rgbsort=rgbsort . "483d8b_DarkSlateBlue" . "\n"
let rgbsort=rgbsort . "6a5acd_SlateBlue" . "\n"
let rgbsort=rgbsort . "8470ff_LightSlateBlue" . "\n"
let rgbsort=rgbsort . "6959cd_SlateBlue3" . "\n"
let rgbsort=rgbsort . "836fff_SlateBlue1" . "\n"
let rgbsort=rgbsort . "473c8b_SlateBlue4" . "\n"
let rgbsort=rgbsort . "7a67ee_SlateBlue2" . "\n"
let rgbsort=rgbsort . "7b68ee_MediumSlateBlue" . "\n"
let rgbsort=rgbsort . "cterm_99_gui_875fff" . "\n"
let rgbsort=rgbsort . "5d478b_MediumPurple4" . "\n"
let rgbsort=rgbsort . "9f79ee_MediumPurple2" . "\n"
let rgbsort=rgbsort . "cterm_141_gui_af87ff" . "\n"
let rgbsort=rgbsort . "9370db_MediumPurple" . "\n"
let rgbsort=rgbsort . "ab82ff_MediumPurple1" . "\n"
let rgbsort=rgbsort . "8968cd_MediumPurple3" . "\n"
let rgbsort=rgbsort . "cterm_98_gui_875fd7" . "\n"
let rgbsort=rgbsort . "cterm_57_gui_5f00ff" . "\n"
let rgbsort=rgbsort . "cterm_56_gui_5f00d7" . "\n"
let rgbsort=rgbsort . "cterm_183_gui_d7afff" . "\n"
let rgbsort=rgbsort . "cterm_140_gui_af87d7" . "\n"
let rgbsort=rgbsort . "cterm_97_gui_875faf" . "\n"
let rgbsort=rgbsort . "cterm_135_gui_af5fff" . "\n"
let rgbsort=rgbsort . "8a2be2_BlueViolet" . "\n"
let rgbsort=rgbsort . "551a8b_purple4" . "\n"
let rgbsort=rgbsort . "9b30ff_purple1" . "\n"
let rgbsort=rgbsort . "7d26cd_purple3" . "\n"
let rgbsort=rgbsort . "912cee_purple2" . "\n"
let rgbsort=rgbsort . "cterm_93_gui_8700ff" . "\n"
let rgbsort=rgbsort . "cterm_55_gui_5f00af" . "\n"
let rgbsort=rgbsort . "a020f0_purple" . "\n"
let rgbsort=rgbsort . "cterm_92_gui_8700d7" . "\n"
let rgbsort=rgbsort . "cterm_177_gui_d787ff" . "\n"
let rgbsort=rgbsort . "cterm_134_gui_af5fd7" . "\n"
let rgbsort=rgbsort . "68228b_DarkOrchid4" . "\n"
let rgbsort=rgbsort . "9932cc_DarkOrchid" . "\n"
let rgbsort=rgbsort . "9a32cd_DarkOrchid3" . "\n"
let rgbsort=rgbsort . "b23aee_DarkOrchid2" . "\n"
let rgbsort=rgbsort . "bf3eff_DarkOrchid1" . "\n"
let rgbsort=rgbsort . "cterm_129_gui_af00ff" . "\n"
let rgbsort=rgbsort . "cterm_54_gui_5f0087" . "\n"
let rgbsort=rgbsort . "9400d3_DarkViolet" . "\n"
let rgbsort=rgbsort . "cterm_171_gui_d75fff" . "\n"
let rgbsort=rgbsort . "cterm_91_gui_8700af" . "\n"
let rgbsort=rgbsort . "ba55d3_MediumOrchid" . "\n"
let rgbsort=rgbsort . "b452cd_MediumOrchid3" . "\n"
let rgbsort=rgbsort . "d15fee_MediumOrchid2" . "\n"
let rgbsort=rgbsort . "e066ff_MediumOrchid1" . "\n"
let rgbsort=rgbsort . "7a378b_MediumOrchid4" . "\n"
let rgbsort=rgbsort . "cterm_128_gui_af00d7" . "\n"
let rgbsort=rgbsort . "cterm_165_gui_d700ff" . "\n"
let rgbsort=rgbsort . "cterm_7_gui_e7e3e7" . "\n"
let rgbsort=rgbsort . "8b7b8b_thistle4" . "\n"
let rgbsort=rgbsort . "cdb5cd_thistle3" . "\n"
let rgbsort=rgbsort . "d8bfd8_thistle" . "\n"
let rgbsort=rgbsort . "eed2ee_thistle2" . "\n"
let rgbsort=rgbsort . "ffe1ff_thistle1" . "\n"
let rgbsort=rgbsort . "cterm_225_gui_ffd7ff" . "\n"
let rgbsort=rgbsort . "cterm_182_gui_d7afd7" . "\n"
let rgbsort=rgbsort . "cterm_139_gui_af87af" . "\n"
let rgbsort=rgbsort . "8b668b_plum4" . "\n"
let rgbsort=rgbsort . "cd96cd_plum3" . "\n"
let rgbsort=rgbsort . "ffbbff_plum1" . "\n"
let rgbsort=rgbsort . "eeaeee_plum2" . "\n"
let rgbsort=rgbsort . "dda0dd_plum" . "\n"
let rgbsort=rgbsort . "cterm_96_gui_875f87" . "\n"
let rgbsort=rgbsort . "cterm_219_gui_ffafff" . "\n"
let rgbsort=rgbsort . "cterm_176_gui_d787d7" . "\n"
let rgbsort=rgbsort . "ee82ee_violet" . "\n"
let rgbsort=rgbsort . "cterm_133_gui_af5faf" . "\n"
let rgbsort=rgbsort . "cterm_213_gui_ff87ff" . "\n"
let rgbsort=rgbsort . "cterm_170_gui_d75fd7" . "\n"
let rgbsort=rgbsort . "cterm_207_gui_ff5fff" . "\n"
let rgbsort=rgbsort . "cterm_53_gui_5f005f" . "\n"
let rgbsort=rgbsort . "cterm_90_gui_870087" . "\n"
let rgbsort=rgbsort . "8b008b_DarkMagenta" . "\n"
let rgbsort=rgbsort . "8b008b_magenta4" . "\n"
let rgbsort=rgbsort . "cterm_127_gui_af00af" . "\n"
let rgbsort=rgbsort . "cd00cd_magenta3" . "\n"
let rgbsort=rgbsort . "cterm_5_gui_ce00ce" . "\n"
let rgbsort=rgbsort . "cterm_164_gui_d700d7" . "\n"
let rgbsort=rgbsort . "ee00ee_magenta2" . "\n"
let rgbsort=rgbsort . "cterm_13_gui_ff00ff" . "\n"
let rgbsort=rgbsort . "cterm_201_gui_ff00ff" . "\n"
let rgbsort=rgbsort . "ff00ff_magenta" . "\n"
let rgbsort=rgbsort . "ff00ff_magenta1" . "\n"
let rgbsort=rgbsort . "cd69c9_orchid3" . "\n"
let rgbsort=rgbsort . "da70d6_orchid" . "\n"
let rgbsort=rgbsort . "ff83fa_orchid1" . "\n"
let rgbsort=rgbsort . "8b4789_orchid4" . "\n"
let rgbsort=rgbsort . "ee7ae9_orchid2" . "\n"
let rgbsort=rgbsort . "cterm_200_gui_ff00d7" . "\n"
let rgbsort=rgbsort . "cterm_163_gui_d700af" . "\n"
let rgbsort=rgbsort . "cterm_126_gui_af0087" . "\n"
let rgbsort=rgbsort . "cterm_206_gui_ff5fd7" . "\n"
let rgbsort=rgbsort . "cterm_89_gui_87005f" . "\n"
let rgbsort=rgbsort . "cterm_199_gui_ff00af" . "\n"
let rgbsort=rgbsort . "cterm_212_gui_ff87d7" . "\n"
let rgbsort=rgbsort . "cterm_169_gui_d75faf" . "\n"
let rgbsort=rgbsort . "ff34b3_maroon1" . "\n"
let rgbsort=rgbsort . "8b1c62_maroon4" . "\n"
let rgbsort=rgbsort . "cd2990_maroon3" . "\n"
let rgbsort=rgbsort . "ee30a7_maroon2" . "\n"
let rgbsort=rgbsort . "d02090_VioletRed" . "\n"
let rgbsort=rgbsort . "c71585_MediumVioletRed" . "\n"
let rgbsort=rgbsort . "cterm_162_gui_d70087" . "\n"
let rgbsort=rgbsort . "8b0a50_DeepPink4" . "\n"
let rgbsort=rgbsort . "cterm_125_gui_af005f" . "\n"
let rgbsort=rgbsort . "cd1076_DeepPink3" . "\n"
let rgbsort=rgbsort . "ff1493_DeepPink" . "\n"
let rgbsort=rgbsort . "ff1493_DeepPink1" . "\n"
let rgbsort=rgbsort . "ee1289_DeepPink2" . "\n"
let rgbsort=rgbsort . "cterm_198_gui_ff0087" . "\n"
let rgbsort=rgbsort . "cterm_218_gui_ffafd7" . "\n"
let rgbsort=rgbsort . "cterm_175_gui_d787af" . "\n"
let rgbsort=rgbsort . "cterm_132_gui_af5f87" . "\n"
let rgbsort=rgbsort . "8b3a62_HotPink4" . "\n"
let rgbsort=rgbsort . "ff69b4_HotPink" . "\n"
let rgbsort=rgbsort . "cterm_205_gui_ff5faf" . "\n"
let rgbsort=rgbsort . "ff6eb4_HotPink1" . "\n"
let rgbsort=rgbsort . "ee6aa7_HotPink2" . "\n"
let rgbsort=rgbsort . "8b2252_VioletRed4" . "\n"
let rgbsort=rgbsort . "cd3278_VioletRed3" . "\n"
let rgbsort=rgbsort . "ee3a8c_VioletRed2" . "\n"
let rgbsort=rgbsort . "ff3e96_VioletRed1" . "\n"
let rgbsort=rgbsort . "cterm_161_gui_d7005f" . "\n"
let rgbsort=rgbsort . "cd6090_HotPink3" . "\n"
let rgbsort=rgbsort . "8b8386_LavenderBlush4" . "\n"
let rgbsort=rgbsort . "b03060_maroon" . "\n"
let rgbsort=rgbsort . "cterm_197_gui_ff005f" . "\n"
let rgbsort=rgbsort . "eee0e5_LavenderBlush2" . "\n"
let rgbsort=rgbsort . "cdc1c5_LavenderBlush3" . "\n"
let rgbsort=rgbsort . "fff0f5_LavenderBlush" . "\n"
let rgbsort=rgbsort . "fff0f5_LavenderBlush1" . "\n"
let rgbsort=rgbsort . "cterm_211_gui_ff87af" . "\n"
let rgbsort=rgbsort . "db7093_PaleVioletRed" . "\n"
let rgbsort=rgbsort . "ff82ab_PaleVioletRed1" . "\n"
let rgbsort=rgbsort . "cd6889_PaleVioletRed3" . "\n"
let rgbsort=rgbsort . "cterm_168_gui_d75f87" . "\n"
let rgbsort=rgbsort . "8b475d_PaleVioletRed4" . "\n"
let rgbsort=rgbsort . "ee799f_PaleVioletRed2" . "\n"
let rgbsort=rgbsort . "cterm_204_gui_ff5f87" . "\n"
let rgbsort=rgbsort . "8b636c_pink4" . "\n"
let rgbsort=rgbsort . "eea9b8_pink2" . "\n"
let rgbsort=rgbsort . "ffb5c5_pink1" . "\n"
let rgbsort=rgbsort . "cd919e_pink3" . "\n"
let rgbsort=rgbsort . "ffc0cb_pink" . "\n"
let rgbsort=rgbsort . "ffb6c1_LightPink" . "\n"
let rgbsort=rgbsort . "eea2ad_LightPink2" . "\n"
let rgbsort=rgbsort . "8b5f65_LightPink4" . "\n"
let rgbsort=rgbsort . "cd8c95_LightPink3" . "\n"
let rgbsort=rgbsort . "ffaeb9_LightPink1" . "\n"

if a:0 == 0 
    return rgbhex1 . rgbhex2 . rgbhex3 . cterm1 . cterm2
endif
if a:0 == 1
    if a:1 == 0 || a:1 == ""
        return rgbhex1 . rgbhex2 . rgbhex3
    elseif a:1 == 1
        return rgbhex1
    elseif a:1 == 2
        return rgbhex2
    elseif a:1 == 3
        return rgbhex3
    elseif a:1 == 4
        return cterm1
    elseif a:1 == 5
        return cterm2
    elseif a:1 == 6
        return cterm1 . cterm2
    elseif a:1 == 7
        return rgbsort
    endif
endif
endfunction

